@@ -283,6 +283,10 @@ void CantorWorksheet::save(QXmlStreamWriter* writer) const{
 
 //! Load from XML
 bool CantorWorksheet::load(XmlStreamReader* reader, bool preview) {
+	//reset the status of the reader differentiating between
+	//"failed because of the missing CAS" and "failed because of the broken XML"
+	reader->setFailedCASMissing(false);
+
 	if (!readBasicAttributes(reader))
 		return false;
 
@@ -316,9 +320,15 @@ bool CantorWorksheet::load(XmlStreamReader* reader, bool preview) {
 
 			QByteArray content = QByteArray::fromBase64(str.toLatin1());
 			rc = init(&content);
-			if  (!rc) {
-				QString msg = i18n("This project has Cantor content but no Cantor plugins were found. Please check your installation. The project will be closed.");
-				reader->raiseError(msg);
+			if (!rc) {
+				reader->raiseMissingCASWarning(m_backendName);
+
+				//failed to load this object because of the missing CAS plugin
+				//and not because of the broken project XML. Set this flag to
+				//handle this case correctly.
+				//TODO: we also can fail in the limit in cases where Cantor's content is broken
+				//and not because of the missing CAS plugin. This also needs to be treated accrodingly...
+				reader->setFailedCASMissing(true);
 				return false;
 			}
 		} else if (!preview && reader->name() == "column") {
