@@ -38,6 +38,7 @@
 #include "backend/lib/SignallingUndoCommand.h"
 #include "backend/lib/PropertyChangeCommand.h"
 #ifdef HAVE_MQTT
+#include "backend/datasources/MQTTClient.h"
 #include "backend/datasources/MQTTSubscription.h"
 #include "backend/datasources/MQTTTopic.h"
 #endif
@@ -237,7 +238,7 @@ bool AbstractAspect::setName(const QString &value, bool autoUnique) {
 
 
 		if (new_name != value)
-			info(i18n("Intended name \"%1\" was changed to \"%2\" in order to avoid name collision.", value, new_name));
+			info(i18n(R"(Intended name "%1" was changed to "%2" in order to avoid name collision.)", value, new_name));
 	} else
 		new_name = value;
 
@@ -420,7 +421,7 @@ void AbstractAspect::addChild(AbstractAspect* child) {
 	QString new_name = uniqueNameFor(child->name());
 	beginMacro(i18n("%1: add %2", name(), new_name));
 	if (new_name != child->name()) {
-		info(i18n("Renaming \"%1\" to \"%2\" in order to avoid name collision.", child->name(), new_name));
+		info(i18n(R"(Renaming "%1" to "%2" in order to avoid name collision.)", child->name(), new_name));
 		child->setName(new_name);
 	}
 
@@ -448,7 +449,7 @@ void AbstractAspect::insertChildBefore(AbstractAspect* child, AbstractAspect* be
 	QString new_name = uniqueNameFor(child->name());
 	beginMacro(before ? i18n("%1: insert %2 before %3", name(), new_name, before->name()) : i18n("%1: insert %2 before end", name(), new_name));
 	if (new_name != child->name()) {
-		info(i18n("Renaming \"%1\" to \"%2\" in order to avoid name collision.", child->name(), new_name));
+		info(i18n(R"(Renaming "%1" to "%2" in order to avoid name collision.)", child->name(), new_name));
 		child->setName(new_name);
 	}
 	int index = d->indexOfChild(before);
@@ -484,6 +485,16 @@ void AbstractAspect::insertChildBeforeFast(AbstractAspect* child, AbstractAspect
  */
 void AbstractAspect::removeChild(AbstractAspect* child) {
 	Q_ASSERT(child->parentAspect() == this);
+
+	//when the child being removed is a LiveDataSource or a MQTT client,
+	//stop reading from the source before removing the child from the project
+	if (child->type() == AspectType::LiveDataSource)
+		static_cast<LiveDataSource*>(child)->pauseReading();
+#ifdef HAVE_MQTT
+	else if (child->type() == AspectType::MQTTClient)
+		static_cast<MQTTClient*>(child)->pauseReading();
+#endif
+
 	beginMacro(i18n("%1: remove %2", name(), child->name()));
 	exec(new AspectChildRemoveCmd(d, child));
 	endMacro();
@@ -523,8 +534,8 @@ void AbstractAspect::removeAllChildren() {
  * \brief Move a child to another parent aspect and transfer ownership.
  */
 void AbstractAspect::reparent(AbstractAspect* newParent, int newIndex) {
-	Q_ASSERT(parentAspect() != nullptr);
-	Q_ASSERT(newParent != nullptr);
+	Q_ASSERT(parentAspect());
+	Q_ASSERT(newParent);
 	int max_index = newParent->childCount<AbstractAspect>(ChildIndexFlag::IncludeHidden);
 	if (newIndex == -1)
 		newIndex = max_index;
@@ -556,6 +567,7 @@ QVector<AbstractAspect*> AbstractAspect::children(AspectType type, ChildIndexFla
 }
 
 const QVector<AbstractAspect*>& AbstractAspect::children() const {
+	Q_ASSERT(d);
 	return d->m_children;
 }
 
