@@ -258,14 +258,45 @@ bool Folder::readChildAspectElement(XmlStreamReader* reader, bool preview) {
 		}
 		addChildFast(worksheet);
 		worksheet->setIsLoading(false);
-#ifdef HAVE_CANTOR_LIBS
 	} else if (element_name == QLatin1String("cantorWorksheet")) {
+#ifdef HAVE_CANTOR_LIBS
 		CantorWorksheet* cantorWorksheet = new CantorWorksheet(QLatin1String("null"), true);
 		if (!cantorWorksheet->load(reader, preview)) {
 			delete cantorWorksheet;
-			return false;
+
+			//if we only failed to load because of the missing CAS, don't return with false here.
+			//in this case we continue loading the project and show a warning about missing CAS at the end.
+			if (!reader->failedCASMissing())
+				return false;
+			else {
+				//failed because of the missing CAS. Read until the end of the current
+				//element in XML and continue loading the project.
+				while (!reader->atEnd()) {
+					reader->readNext();
+					if (reader->isEndElement() && reader->name() == QLatin1String("cantorWorksheet"))
+						break;
+				}
+			}
+		} else
+			addChildFast(cantorWorksheet);
+#else
+	if (!preview) {
+		while (!reader->atEnd()) {
+			reader->readNext();
+			if (reader->isEndElement() && reader->name() == QLatin1String("cantorWorksheet"))
+				break;
+
+			if (!reader->isStartElement())
+				continue;
+
+			if (reader->name() == QLatin1String("general")) {
+				const QString& backendName = reader->attributes().value("backend_name").toString().trimmed();
+				if (!backendName.isEmpty())
+					reader->raiseMissingCASWarning(backendName);
+			} else
+				reader->skipToEndElement();
 		}
-		addChildFast(cantorWorksheet);
+	}
 #endif
 #ifdef HAVE_MQTT
 	} else if (element_name == QLatin1String("MQTTClient")) {
