@@ -222,66 +222,15 @@ void Project::descriptionChanged(const AbstractAspect* aspect) {
 	if (isLoading())
 		return;
 
-	if (this != aspect) {
-		const auto* column = dynamic_cast<const AbstractColumn*>(aspect);
-		if (!column)
-			return;
+	//when the name of a column is being changed, it can match again the names being used in the curves, etc.
+	//and we need to update the dependencies
+	const auto* column = dynamic_cast<const AbstractColumn*>(aspect);
+	if (column) {
+		const auto& curves = children<XYCurve>(ChildIndexFlag::Recursive);
+		updateCurveColumnDependencies(curves, column);
 
-		// When the column is created, it gets a random name and is eventually not connected to any curve.
-		// When changing the name it can match a curve and should than be connected to the curve.
-		const QVector<XYCurve*>& curves = children<XYCurve>(ChildIndexFlag::Recursive);
-		QString columnPath = column->path();
-
-		// setXColumnPath must not be set, because if curve->column matches column, there already exist a
-		// signal/slot connection between the curve and the column to update this. If they are not same,
-		// xColumnPath is set in setXColumn. Same for the yColumn.
-		for (auto* curve : curves) {
-			curve->setUndoAware(false);
-			auto* analysisCurve = dynamic_cast<XYAnalysisCurve*>(curve);
-			if (analysisCurve) {
-				if (analysisCurve->xDataColumnPath() == columnPath)
-					analysisCurve->setXDataColumn(column);
-				if (analysisCurve->yDataColumnPath() == columnPath)
-					analysisCurve->setYDataColumn(column);
-				if (analysisCurve->y2DataColumnPath() == columnPath)
-					analysisCurve->setY2DataColumn(column);
-
-				auto* fitCurve = dynamic_cast<XYFitCurve*>(curve);
-				if (fitCurve) {
-					if (fitCurve->xErrorColumnPath() == columnPath)
-						fitCurve->setXErrorColumn(column);
-					if (fitCurve->yErrorColumnPath() == columnPath)
-						fitCurve->setYErrorColumn(column);
-				}
-			} else {
-				if (curve->xColumnPath() == columnPath)
-					curve->setXColumn(column);
-				if (curve->yColumnPath() == columnPath)
-					curve->setYColumn(column);
-				if (curve->valuesColumnPath() == columnPath)
-					curve->setValuesColumn(column);
-				if (curve->xErrorPlusColumnPath() == columnPath)
-					curve->setXErrorPlusColumn(column);
-				if (curve->xErrorMinusColumnPath() == columnPath)
-					curve->setXErrorMinusColumn(column);
-				if (curve->yErrorPlusColumnPath() == columnPath)
-					curve->setYErrorPlusColumn(column);
-				if (curve->yErrorMinusColumnPath() == columnPath)
-					curve->setYErrorMinusColumn(column);
-			}
-			curve->setUndoAware(true);
-
-		}
-
-		const QVector<Column*>& columns = children<Column>(ChildIndexFlag::Recursive);
-		for (auto* tempColumn : columns) {
-			const QStringList& formulaVariableColumnsPath = tempColumn->formulaVariableColumnPaths();
-			for (int i = 0; i < formulaVariableColumnsPath.count(); i++) {
-				if (formulaVariableColumnsPath.at(i) == columnPath)
-					tempColumn->setformulVariableColumn(i, const_cast<Column*>(static_cast<const Column*>(column)));
-			}
-		}
-		return;
+		const auto& histograms = children<Histogram>(ChildIndexFlag::Recursive);
+		updateHistogramColumnDependencies(histograms, column);
 	}
 
 	d->changed = true;
@@ -294,78 +243,113 @@ void Project::descriptionChanged(const AbstractAspect* aspect) {
  * \param aspect
  */
 void Project::aspectAddedSlot(const AbstractAspect* aspect) {
-
-	const QVector<AbstractAspect*>& _children = aspect->children(AspectType::Column, ChildIndexFlag::Recursive);
+	//check whether new columns were added and if yes,
+	//update the dependencies in the project
 	QVector<const AbstractColumn*> columns;
-	for (auto child : _children)
-		columns.append(static_cast<const AbstractColumn*>(child));
-
 	const auto* column = dynamic_cast<const AbstractColumn*>(aspect);
 	if (column)
 		columns.append(column);
+	else {
+		for (auto* child : aspect->children<Column>(ChildIndexFlag::Recursive))
+			columns.append(static_cast<const AbstractColumn*>(child));
+	}
 
 	if (columns.isEmpty())
 		return;
 
-	for (auto column : columns) {
-		const QVector<XYCurve*>& curves = children<XYCurve>(ChildIndexFlag::Recursive);
-		QString columnPath = column->path();
-
-		for (auto* curve : curves) {
-			curve->setUndoAware(false);
-			auto* analysisCurve = dynamic_cast<XYAnalysisCurve*>(curve);
-			if (analysisCurve) {
-				if (analysisCurve->xDataColumnPath() == columnPath)
-					analysisCurve->setXDataColumn(column);
-				if (analysisCurve->yDataColumnPath() == columnPath)
-					analysisCurve->setYDataColumn(column);
-				if (analysisCurve->y2DataColumnPath() == columnPath)
-					analysisCurve->setY2DataColumn(column);
-
-				auto* fitCurve = dynamic_cast<XYFitCurve*>(curve);
-				if (fitCurve) {
-					if (fitCurve->xErrorColumnPath() == columnPath)
-						fitCurve->setXErrorColumn(column);
-					if (fitCurve->yErrorColumnPath() == columnPath)
-						fitCurve->setYErrorColumn(column);
-				}
-			} else {
-				if (curve->xColumnPath() == columnPath)
-					curve->setXColumn(column);
-				if (curve->yColumnPath() == columnPath)
-					curve->setYColumn(column);
-				if (curve->valuesColumnPath() == columnPath)
-					curve->setValuesColumn(column);
-				if (curve->xErrorPlusColumnPath() == columnPath)
-					curve->setXErrorPlusColumn(column);
-				if (curve->xErrorMinusColumnPath() == columnPath)
-					curve->setXErrorMinusColumn(column);
-				if (curve->yErrorPlusColumnPath() == columnPath)
-					curve->setYErrorPlusColumn(column);
-				if (curve->yErrorMinusColumnPath() == columnPath)
-					curve->setYErrorMinusColumn(column);
-			}
-			curve->setUndoAware(true);
-		}
-		const QVector<Column*>& columns = children<Column>(ChildIndexFlag::Recursive);
-		for (auto* tempColumn : columns) {
-			const QStringList& formulaVariableColumnPaths = tempColumn->formulaVariableColumnPaths();
-			for (int i = 0; i < formulaVariableColumnPaths.count(); i++) {
-				if (formulaVariableColumnPaths.at(i) == column->path())
-					tempColumn->setformulVariableColumn(i, const_cast<Column*>(static_cast<const Column*>(column)));
-			}
-		}
-	}
+	//if a new column was addded, check whether the column names match the missing
+	//names in the curves, etc. and update the dependencies
+	const auto& curves = children<XYCurve>(ChildIndexFlag::Recursive);
+	for (auto column : columns)
+		updateCurveColumnDependencies(curves, column);
 
+	const auto& histograms = children<Histogram>(ChildIndexFlag::Recursive);
+	for (auto column : columns)
+		updateHistogramColumnDependencies(histograms, column);
 }
 
+void Project::updateCurveColumnDependencies(const QVector<XYCurve*>& curves, const AbstractColumn* column) const {
+	const QString& columnPath = column->path();
+
+	// setXColumnPath must not be set, because if curve->column matches column, there already exist a
+	// signal/slot connection between the curve and the column to update this. If they are not same,
+	// xColumnPath is set in setXColumn. Same for the yColumn.
+	for (auto* curve : curves) {
+		curve->setUndoAware(false);
+		auto* analysisCurve = dynamic_cast<XYAnalysisCurve*>(curve);
+		if (analysisCurve) {
+			if (analysisCurve->xDataColumnPath() == columnPath)
+				analysisCurve->setXDataColumn(column);
+			if (analysisCurve->yDataColumnPath() == columnPath)
+				analysisCurve->setYDataColumn(column);
+			if (analysisCurve->y2DataColumnPath() == columnPath)
+				analysisCurve->setY2DataColumn(column);
+
+			auto* fitCurve = dynamic_cast<XYFitCurve*>(curve);
+			if (fitCurve) {
+				if (fitCurve->xErrorColumnPath() == columnPath)
+					fitCurve->setXErrorColumn(column);
+				if (fitCurve->yErrorColumnPath() == columnPath)
+					fitCurve->setYErrorColumn(column);
+			}
+		} else {
+			if (curve->xColumnPath() == columnPath)
+				curve->setXColumn(column);
+			if (curve->yColumnPath() == columnPath)
+				curve->setYColumn(column);
+			if (curve->valuesColumnPath() == columnPath)
+				curve->setValuesColumn(column);
+			if (curve->xErrorPlusColumnPath() == columnPath)
+				curve->setXErrorPlusColumn(column);
+			if (curve->xErrorMinusColumnPath() == columnPath)
+				curve->setXErrorMinusColumn(column);
+			if (curve->yErrorPlusColumnPath() == columnPath)
+				curve->setYErrorPlusColumn(column);
+			if (curve->yErrorMinusColumnPath() == columnPath)
+				curve->setYErrorMinusColumn(column);
+		}
+
+		if (curve->valuesColumnPath() == columnPath)
+			curve->setValuesColumn(column);
+
+		curve->setUndoAware(true);
+	}
+
+	const QVector<Column*>& columns = children<Column>(ChildIndexFlag::Recursive);
+	for (auto* tempColumn : columns) {
+		const QStringList& paths = tempColumn->formulaVariableColumnPaths();
+		for (int i = 0; i < paths.count(); i++) {
+			if (paths.at(i) == columnPath)
+				tempColumn->setformulVariableColumn(i, const_cast<Column*>(static_cast<const Column*>(column)));
+		}
+	}
+}
+
+void Project::updateHistogramColumnDependencies(const QVector<Histogram*>& histograms, const AbstractColumn* column) const {
+	const QString& columnPath = column->path();
+	for (auto* histogram : histograms) {
+		if (histogram->dataColumnPath() == columnPath) {
+			histogram->setUndoAware(false);
+			histogram->setDataColumn(column);
+			histogram->setUndoAware(true);
+		}
+
+		if (histogram->valuesColumnPath() == columnPath) {
+			histogram->setUndoAware(false);
+			histogram->setValuesColumn(column);
+			histogram->setUndoAware(true);
+		}
+	}
+}
 void Project::navigateTo(const QString& path) {
 	emit requestNavigateTo(path);
 }
 
 bool Project::isLabPlotProject(const QString& fileName) {
-	return fileName.endsWith(QStringLiteral(".lml"), Qt::CaseInsensitive) || fileName.endsWith(QStringLiteral(".lml.gz"), Qt::CaseInsensitive)
-		|| fileName.endsWith(QStringLiteral(".lml.bz2"), Qt::CaseInsensitive) || fileName.endsWith(QStringLiteral(".lml.xz"), Qt::CaseInsensitive);
+	return fileName.endsWith(QStringLiteral(".lml"), Qt::CaseInsensitive)
+			|| fileName.endsWith(QStringLiteral(".lml.gz"), Qt::CaseInsensitive)
+			|| fileName.endsWith(QStringLiteral(".lml.bz2"), Qt::CaseInsensitive)
+			|| fileName.endsWith(QStringLiteral(".lml.xz"), Qt::CaseInsensitive);
 }
 
 QString Project::supportedExtensions() {
@@ -478,6 +462,8 @@ bool Project::load(const QString& filename, bool preview) {
 		if (msg.isEmpty())
 			msg = i18n("Unknown error when opening the project %1.", filename);
 		KMessageBox::error(nullptr, msg, i18n("Error when opening the project"));
+		file->close();
+		delete file;
 		return false;
 	}
 
@@ -491,6 +477,22 @@ bool Project::load(const QString& filename, bool preview) {
 // 		KMessageBox::error(this, msg, i18n("Project loading partly failed"));
 	}
 
+	if (reader.hasMissingCASWarnings()) {
+		RESET_CURSOR;
+
+		const QString& msg = i18n("The project has content written with %1. "
+						"Your installation of LabPlot lacks the support for it.\n\n "
+						"You won't be able to see this part of the project. "
+						"If you modify and save the project, the CAS content will be lost.\n\n"
+						"Do you want to continue?", reader.missingCASWarning());
+		auto rc = KMessageBox::warningYesNo(nullptr, msg, i18n("Missing Support for CAS"));
+		if (rc == KMessageBox::ButtonCode::No) {
+			file->close();
+			delete file;
+			return false;
+		}
+	}
+
 	file->close();
 	delete file;
 
@@ -613,6 +615,7 @@ bool Project::load(XmlStreamReader* reader, bool preview) {
 		for (auto* hist : hists) {
 			if (!hist) continue;
 			RESTORE_COLUMN_POINTER(hist, dataColumn, DataColumn);
+			RESTORE_COLUMN_POINTER(hist, valuesColumn, ValuesColumn);
 		}
 
 		//data picker curves
