@@ -33,6 +33,9 @@
 #include "backend/core/Folder.h"
 #include "backend/lib/macros.h"
 
+class AbstractColumn;
+class Histogram;
+class XYCurve;
 class QMimeData;
 class QString;
 
@@ -105,6 +108,8 @@ signals:
 
 private:
 	Private* d;
+	void updateCurveColumnDependencies(const QVector<XYCurve*>&, const AbstractColumn*) const;
+	void updateHistogramColumnDependencies(const QVector<Histogram*>&, const AbstractColumn*) const;
 	bool readProjectAttributes(XmlStreamReader*);
 	void save(QXmlStreamWriter*) const override;
 };
