@@ -30,7 +30,6 @@
 #define WORKBOOK_H
 
 #include "backend/core/AbstractPart.h"
-#include "backend/core/AbstractScriptingEngine.h"
 
 class Spreadsheet;
 class Matrix;
@@ -38,11 +37,11 @@ class WorkbookView;
 class QXmlStreamWriter;
 class XmlStreamReader;
 
-class Workbook : public AbstractPart, public scripted {
+class Workbook : public AbstractPart {
 	Q_OBJECT
 
 public:
-	Workbook(AbstractScriptingEngine* engine, const QString& name);
+	explicit Workbook(const QString& name);
 
 	QIcon icon() const override;
 	QMenu* createContextMenu() override;
@@ -63,7 +62,7 @@ public slots:
 	void childSelected(const AbstractAspect*) override;
 
 private:
-	mutable WorkbookView* m_view;
+	mutable WorkbookView* m_view{nullptr};
 
 private slots:
 	void childDeselected(const AbstractAspect*) override;
