@@ -5,6 +5,7 @@
     --------------------------------------------------------------------
     Copyright            : (C) 2007,2008 Tilman Benkert (thzs@gmx.net)
     Copyright            : (C) 2013-2019 Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2020 Stefan Gerlach (stefan.gerlach@uni.kn)
 
  ***************************************************************************/
 
@@ -52,6 +53,7 @@ public:
 	bool copy(const ColumnPrivate*, int source_start, int dest_start, int num_rows);
 
 	int rowCount() const;
+	int availableRowCount() const;
 	void resizeTo(int);
 
 	void insertRows(int before, int count);
@@ -80,7 +82,7 @@ public:
 	const QStringList& formulaVariableNames() const;
 	const QVector<Column*>& formulaVariableColumns() const;
 	const QStringList& formulaVariableColumnPaths() const;
-	void setformulVariableColumnsPath(int index, QString path);
+	void setformulVariableColumnsPath(int index, const QString& path);
 	void setformulVariableColumn(int index, Column *column);
 	bool formulaAutoUpdate() const;
 	void setFormula(const QString& formula, const QStringList& variableNames,
@@ -92,8 +94,8 @@ public:
 	//cell formulas
 	QString formula(int row) const;
 	QVector< Interval<int> > formulaIntervals() const;
-	void setFormula(Interval<int> i, QString formula);
-	void setFormula(int row, QString formula);
+	void setFormula(const Interval<int>& i, const QString& formula);
+	void setFormula(int row, const QString& formula);
 	void clearFormulas();
 
 	QString textAt(int row) const;
@@ -116,8 +118,12 @@ public:
 	void setIntegerAt(int row, int new_value);
 	void replaceInteger(int first, const QVector<int>&);
 
-	void updateProperties();
+	qint64 bigIntAt(int row) const;
+	void setBigIntAt(int row, qint64 new_value);
+	void replaceBigInt(int first, const QVector<qint64>&);
 
+	void updateProperties();
+	void invalidate();
 	void finalizeLoad();
 
 	mutable AbstractColumn::ColumnStatistics statistics;
@@ -130,8 +136,10 @@ public:
 	mutable AbstractColumn::Properties properties{AbstractColumn::Properties::No}; // declares the properties of the curve (monotonic increasing/decreasing ...). Speed up algorithms
 
 private:
+	//TODO: rename to m_columnMode
 	AbstractColumn::ColumnMode m_column_mode;	// type of column data
 	void* m_data{nullptr};	//pointer to the data container (QVector<T>)
+	// TODO: rename to m_InputFilter, m_OutputFilter
 	AbstractSimpleFilter* m_input_filter{nullptr};	//input filter for string -> data type conversion
 	AbstractSimpleFilter* m_output_filter{nullptr};	//output filter for data type -> string conversion
 	QString m_formula;
@@ -140,7 +148,8 @@ private:
 	QStringList m_formulaVariableColumnPaths;
 	bool m_formulaAutoUpdate{false};
 	IntervalAttribute<QString> m_formulas;
-	AbstractColumn::PlotDesignation m_plot_designation{AbstractColumn::NoDesignation};
+	//TODO: rename to m_plotDesignation
+	AbstractColumn::PlotDesignation m_plot_designation{AbstractColumn::PlotDesignation::NoDesignation};
 	int m_width{0}; //column width in the view
 	Column* m_owner{nullptr};
 	QVector<QMetaObject::Connection> m_connectionsUpdateFormula;
