@@ -59,11 +59,11 @@ public:
 	}
 
 	//! Return the data type of the column
-	AbstractColumn::ColumnMode columnMode() const override { return AbstractColumn::Month; }
+	AbstractColumn::ColumnMode columnMode() const override { return AbstractColumn::ColumnMode::Month; }
 
 protected:
 	bool inputAcceptable(int, const AbstractColumn *source) override {
-		return source->columnMode() == AbstractColumn::Numeric;
+		return source->columnMode() == AbstractColumn::ColumnMode::Numeric;
 	}
 };
 
