@@ -46,7 +46,7 @@
  * \brief A customizable error-bar for DatapickerPoint.
  */
 
-ErrorBarItem::ErrorBarItem(DatapickerPoint* parent, const ErrorBarType& type) :
+ErrorBarItem::ErrorBarItem(DatapickerPoint* parent, ErrorBarType type) :
 	QGraphicsRectItem(parent->graphicsItem()),
 	barLineItem(new QGraphicsLineItem(parent->graphicsItem())),
 	m_type(type),
@@ -62,38 +62,38 @@ void ErrorBarItem::initRect() {
 	QRectF xBarRect(-0.15, -0.5, 0.3, 1);
 	QRectF yBarRect(-0.5, -0.15, 1, 0.3);
 
-	if (m_type == PlusDeltaX || m_type == MinusDeltaX)
+	if (m_type == ErrorBarType::PlusDeltaX || m_type == ErrorBarType::MinusDeltaX)
 		m_rect = xBarRect;
 	else
 		m_rect = yBarRect;
 }
 
-void ErrorBarItem::setPosition(const QPointF& position) {
+void ErrorBarItem::setPosition(QPointF position) {
 	setPos(position);
 	barLineItem->setLine(0, 0, position.x(), position.y());
 }
 
-void ErrorBarItem::setRectSize(const qreal size) {
+void ErrorBarItem::setRectSize(qreal size) {
 	QMatrix matrix;
 	matrix.scale(size, size);
 	setRect(matrix.mapRect(m_rect));
 }
 
 void ErrorBarItem::mouseReleaseEvent(QGraphicsSceneMouseEvent* event) {
-	if (m_type == PlusDeltaX)
+	if (m_type == ErrorBarType::PlusDeltaX)
 		m_parentItem->setPlusDeltaXPos(pos());
-	else if (m_type == MinusDeltaX)
+	else if (m_type == ErrorBarType::MinusDeltaX)
 		m_parentItem->setMinusDeltaXPos(pos());
-	else if (m_type == PlusDeltaY)
+	else if (m_type == ErrorBarType::PlusDeltaY)
 		m_parentItem->setPlusDeltaYPos(pos());
-	else if (m_type == MinusDeltaY)
+	else if (m_type == ErrorBarType::MinusDeltaY)
 		m_parentItem->setMinusDeltaYPos(pos());
 
 	QGraphicsItem::mouseReleaseEvent(event);
 }
 
 void ErrorBarItem::hoverEnterEvent(QGraphicsSceneHoverEvent*) {
-	if (m_type == PlusDeltaX ||m_type == MinusDeltaX)
+	if (m_type == ErrorBarType::PlusDeltaX ||m_type == ErrorBarType::MinusDeltaX)
 		setCursor(Qt::SizeHorCursor);
 	else
 		setCursor(Qt::SizeVerCursor);
@@ -102,7 +102,7 @@ void ErrorBarItem::hoverEnterEvent(QGraphicsSceneHoverEvent*) {
 QVariant ErrorBarItem::itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant &value) {
 	if (change == QGraphicsItem::ItemPositionChange) {
 		QPointF newPos = value.toPointF();
-		if (m_type == PlusDeltaX || m_type == MinusDeltaX) {
+		if (m_type == ErrorBarType::PlusDeltaX || m_type == ErrorBarType::MinusDeltaX) {
 			newPos.setY(0);
 			barLineItem->setLine(0, 0, newPos.x(), 0);
 		} else {
@@ -122,7 +122,7 @@ QVariant ErrorBarItem::itemChange(QGraphicsItem::GraphicsItemChange change, cons
  * The datapicker-Point is aligned relative to the specified position.
  * The position can be either specified by mouse events or by providing the
  * x- and y- coordinates in parent's coordinate system, or by specifying one
- * of the predefined position flags (\ca HorizontalPosition, \ca VerticalPosition).
+ * of the predefined position flags (\c HorizontalPosition, \c VerticalPosition).
  */
 
 DatapickerPoint::DatapickerPoint(const QString& name)
@@ -147,34 +147,34 @@ void DatapickerPoint::init() {
 	KConfig config;
 	KConfigGroup group;
 	group = config.group("DatapickerPoint");
-	d->position.setX( group.readEntry("PositionXValue", Worksheet::convertToSceneUnits(1, Worksheet::Centimeter)) );
-	d->position.setY( group.readEntry("PositionYValue", Worksheet::convertToSceneUnits(1, Worksheet::Centimeter)) );
+	d->position.setX( group.readEntry("PositionXValue", Worksheet::convertToSceneUnits(1, Worksheet::Unit::Centimeter)) );
+	d->position.setY( group.readEntry("PositionYValue", Worksheet::convertToSceneUnits(1, Worksheet::Unit::Centimeter)) );
 	d->plusDeltaXPos = group.readEntry("PlusDeltaXPos", QPointF(30, 0));
 	d->minusDeltaXPos = group.readEntry("MinusDeltaXPos", QPointF(-30, 0));
 	d->plusDeltaYPos = group.readEntry("PlusDeltaYPos", QPointF(0, -30));
 	d->minusDeltaYPos = group.readEntry("MinusDeltaYPos", QPointF(0, 30));
 }
 
-void DatapickerPoint::initErrorBar(const DatapickerCurve::Errors& errors) {
+void DatapickerPoint::initErrorBar(DatapickerCurve::Errors errors) {
 	m_errorBarItemList.clear();
-	if (errors.x != DatapickerCurve::NoError) {
-		ErrorBarItem* plusDeltaXItem = new ErrorBarItem(this, ErrorBarItem::PlusDeltaX);
+	if (errors.x != DatapickerCurve::ErrorType::NoError) {
+		auto* plusDeltaXItem = new ErrorBarItem(this, ErrorBarItem::ErrorBarType::PlusDeltaX);
 		plusDeltaXItem->setPosition(plusDeltaXPos());
 		connect(this, &DatapickerPoint::plusDeltaXPosChanged, plusDeltaXItem, &ErrorBarItem::setPosition);
 
-		ErrorBarItem* minusDeltaXItem = new ErrorBarItem(this, ErrorBarItem::MinusDeltaX);
+		auto* minusDeltaXItem = new ErrorBarItem(this, ErrorBarItem::ErrorBarType::MinusDeltaX);
 		minusDeltaXItem->setPosition(minusDeltaXPos());
 		connect(this, &DatapickerPoint::minusDeltaXPosChanged, minusDeltaXItem, &ErrorBarItem::setPosition);
 
 		m_errorBarItemList<<plusDeltaXItem<<minusDeltaXItem;
 	}
 
-	if (errors.y != DatapickerCurve::NoError) {
-		ErrorBarItem* plusDeltaYItem = new ErrorBarItem(this, ErrorBarItem::PlusDeltaY);
+	if (errors.y != DatapickerCurve::ErrorType::NoError) {
+		auto* plusDeltaYItem = new ErrorBarItem(this, ErrorBarItem::ErrorBarType::PlusDeltaY);
 		plusDeltaYItem->setPosition(plusDeltaYPos());
 		connect(this, &DatapickerPoint::plusDeltaYPosChanged, plusDeltaYItem, &ErrorBarItem::setPosition);
 
-		ErrorBarItem* minusDeltaYItem = new ErrorBarItem(this, ErrorBarItem::MinusDeltaY);
+		auto* minusDeltaYItem = new ErrorBarItem(this, ErrorBarItem::ErrorBarType::MinusDeltaY);
 		minusDeltaYItem->setPosition(minusDeltaYPos());
 		connect(this, &DatapickerPoint::minusDeltaYPosChanged, minusDeltaYItem, &ErrorBarItem::setPosition);
 
@@ -221,14 +221,14 @@ CLASS_SHARED_D_READER_IMPL(DatapickerPoint, QPointF, minusDeltaYPos, minusDeltaY
 
 /* ============================ setter methods and undo commands ================= */
 STD_SETTER_CMD_IMPL_F_S(DatapickerPoint, SetPosition, QPointF, position, retransform)
-void DatapickerPoint::setPosition(const QPointF& pos) {
+void DatapickerPoint::setPosition(QPointF pos) {
 	Q_D(DatapickerPoint);
 	if (pos != d->position)
 		exec(new DatapickerPointSetPositionCmd(d, pos, ki18n("%1: set position")));
 }
 
 STD_SETTER_CMD_IMPL_F_S(DatapickerPoint, SetPlusDeltaXPos, QPointF, plusDeltaXPos, updatePoint)
-void DatapickerPoint::setPlusDeltaXPos(const QPointF& pos) {
+void DatapickerPoint::setPlusDeltaXPos(QPointF pos) {
 	Q_D(DatapickerPoint);
 	if (pos != d->plusDeltaXPos) {
 		auto* curve = dynamic_cast<DatapickerCurve*>(parentAspect());
@@ -236,7 +236,7 @@ void DatapickerPoint::setPlusDeltaXPos(const QPointF& pos) {
 			return;
 
 		beginMacro(i18n("%1: set +delta_X position", name()));
-		if (curve->curveErrorTypes().x == DatapickerCurve::SymmetricError) {
+		if (curve->curveErrorTypes().x == DatapickerCurve::ErrorType::SymmetricError) {
 			exec(new DatapickerPointSetPlusDeltaXPosCmd(d, pos, ki18n("%1: set +delta X position")));
 			setMinusDeltaXPos(QPointF(-qAbs(pos.x()), pos.y()));
 		} else
@@ -246,7 +246,7 @@ void DatapickerPoint::setPlusDeltaXPos(const QPointF& pos) {
 }
 
 STD_SETTER_CMD_IMPL_F_S(DatapickerPoint, SetMinusDeltaXPos, QPointF, minusDeltaXPos, updatePoint)
-void DatapickerPoint::setMinusDeltaXPos(const QPointF& pos) {
+void DatapickerPoint::setMinusDeltaXPos(QPointF pos) {
 	Q_D(DatapickerPoint);
 	if (pos != d->minusDeltaXPos) {
 		auto* curve = dynamic_cast<DatapickerCurve*>(parentAspect());
@@ -254,7 +254,7 @@ void DatapickerPoint::setMinusDeltaXPos(const QPointF& pos) {
 			return;
 
 		beginMacro(i18n("%1: set -delta_X position", name()));
-		if (curve->curveErrorTypes().x == DatapickerCurve::SymmetricError) {
+		if (curve->curveErrorTypes().x == DatapickerCurve::ErrorType::SymmetricError) {
 			exec(new DatapickerPointSetMinusDeltaXPosCmd(d, pos, ki18n("%1: set -delta_X position")));
 			setPlusDeltaXPos(QPointF(qAbs(pos.x()), pos.y()));
 		} else
@@ -264,7 +264,7 @@ void DatapickerPoint::setMinusDeltaXPos(const QPointF& pos) {
 }
 
 STD_SETTER_CMD_IMPL_F_S(DatapickerPoint, SetPlusDeltaYPos, QPointF, plusDeltaYPos, updatePoint)
-void DatapickerPoint::setPlusDeltaYPos(const QPointF& pos) {
+void DatapickerPoint::setPlusDeltaYPos(QPointF pos) {
 	Q_D(DatapickerPoint);
 	if (pos != d->plusDeltaYPos) {
 		auto* curve = dynamic_cast<DatapickerCurve*>(parentAspect());
@@ -272,7 +272,7 @@ void DatapickerPoint::setPlusDeltaYPos(const QPointF& pos) {
 			return;
 
 		beginMacro(i18n("%1: set +delta_Y position", name()));
-		if (curve->curveErrorTypes().y == DatapickerCurve::SymmetricError) {
+		if (curve->curveErrorTypes().y == DatapickerCurve::ErrorType::SymmetricError) {
 			exec(new DatapickerPointSetPlusDeltaYPosCmd(d, pos, ki18n("%1: set +delta_Y position")));
 			setMinusDeltaYPos(QPointF(pos.x(), qAbs(pos.y())));
 		} else
@@ -282,7 +282,7 @@ void DatapickerPoint::setPlusDeltaYPos(const QPointF& pos) {
 }
 
 STD_SETTER_CMD_IMPL_F_S(DatapickerPoint, SetMinusDeltaYPos, QPointF, minusDeltaYPos, updatePoint)
-void DatapickerPoint::setMinusDeltaYPos(const QPointF& pos) {
+void DatapickerPoint::setMinusDeltaYPos(QPointF pos) {
 	Q_D(DatapickerPoint);
 	if (pos != d->minusDeltaYPos) {
 		auto* curve = dynamic_cast<DatapickerCurve*>(parentAspect());
@@ -290,7 +290,7 @@ void DatapickerPoint::setMinusDeltaYPos(const QPointF& pos) {
 			return;
 
 		beginMacro(i18n("%1: set -delta_Y position", name()));
-		if (curve->curveErrorTypes().y == DatapickerCurve::SymmetricError) {
+		if (curve->curveErrorTypes().y == DatapickerCurve::ErrorType::SymmetricError) {
 			exec(new DatapickerPointSetMinusDeltaYPosCmd(d, pos, ki18n("%1: set -delta_Y position")));
 			setPlusDeltaYPos(QPointF(pos.x(), -qAbs(pos.y())));
 		} else
@@ -469,8 +469,8 @@ void DatapickerPoint::save(QXmlStreamWriter* writer) const {
 	writer->writeEndElement();
 
 	auto* curve = dynamic_cast<DatapickerCurve*>(parentAspect());
-	if (curve && (curve->curveErrorTypes().x != DatapickerCurve::NoError
-		|| curve->curveErrorTypes().y != DatapickerCurve::NoError)) {
+	if (curve && (curve->curveErrorTypes().x != DatapickerCurve::ErrorType::NoError
+		|| curve->curveErrorTypes().y != DatapickerCurve::ErrorType::NoError)) {
 
 		writer->writeStartElement( "errorBar" );
 		writer->writeAttribute( "plusDeltaXPos_x", QString::number(d->plusDeltaXPos.x()) );
