@@ -27,6 +27,7 @@
 #ifndef SEGMENT_H
 #define SEGMENT_H
 
+#include <QVector>
 #include "backend/lib/macros.h"
 
 class QGraphicsItem;
@@ -39,7 +40,7 @@ class Segment {
 public:
 	explicit Segment(DatapickerImage*);
 
-	QList<QLine*> path;
+	QVector<QLine*> path;
 	int yLast{0};
 	int length{0};
 
