@@ -26,12 +26,18 @@
  ***************************************************************************/
 
 #include "Transform.h"
+//TODO: replace with GSL or better methods
 #include <cmath>
 
-Transform::Transform() = default;
+extern "C" {
+#include <gsl/gsl_math.h>
+#include "backend/nsl/nsl_math.h"
+}
+
+//Transform::Transform() = default;
 
 bool Transform::mapTypeToCartesian(const DatapickerImage::ReferencePoints& axisPoints) {
-	if (axisPoints.type == DatapickerImage::LogarithmicX) {
+	if (axisPoints.type == DatapickerImage::GraphType::LogarithmicX) {
 		for (int i = 0; i < 3; ++i) {
 			if (axisPoints.logicalPos[i].x() <= 0)
 				return false;
@@ -40,7 +46,7 @@ bool Transform::mapTypeToCartesian(const DatapickerImage::ReferencePoints& axisP
 			X[i] = axisPoints.scenePos[i].x();
 			Y[i] = axisPoints.scenePos[i].y();
 		}
-	} else if (axisPoints.type == DatapickerImage::LogarithmicY) {
+	} else if (axisPoints.type == DatapickerImage::GraphType::LogarithmicY) {
 		for (int i = 0; i < 3; ++i) {
 			if (axisPoints.logicalPos[i].y() <= 0)
 				return false;
@@ -49,16 +55,16 @@ bool Transform::mapTypeToCartesian(const DatapickerImage::ReferencePoints& axisP
 			X[i] = axisPoints.scenePos[i].x();
 			Y[i] = axisPoints.scenePos[i].y();
 		}
-	} else if (axisPoints.type == DatapickerImage::PolarInDegree) {
+	} else if (axisPoints.type == DatapickerImage::GraphType::PolarInDegree) {
 		for (int i = 0; i < 3; ++i) {
 			if (axisPoints.logicalPos[i].x() < 0)
 				return false;
-			x[i] = axisPoints.logicalPos[i].x()*cos(axisPoints.logicalPos[i].y()*M_PI / 180.0);
-			y[i] = axisPoints.logicalPos[i].x()*sin(axisPoints.logicalPos[i].y()*M_PI / 180.0);
+			x[i] = axisPoints.logicalPos[i].x()*cos(axisPoints.logicalPos[i].y() * M_PI_180);
+			y[i] = axisPoints.logicalPos[i].x()*sin(axisPoints.logicalPos[i].y() * M_PI_180);
 			X[i] = axisPoints.scenePos[i].x();
 			Y[i] = axisPoints.scenePos[i].y();
 		}
-	} else if (axisPoints.type == DatapickerImage::PolarInRadians) {
+	} else if (axisPoints.type == DatapickerImage::GraphType::PolarInRadians) {
 		for (int i = 0; i < 3; ++i) {
 			if (axisPoints.logicalPos[i].x() < 0)
 				return false;
@@ -67,10 +73,10 @@ bool Transform::mapTypeToCartesian(const DatapickerImage::ReferencePoints& axisP
 			X[i] = axisPoints.scenePos[i].x();
 			Y[i] = axisPoints.scenePos[i].y();
 		}
-	} else if (axisPoints.type == DatapickerImage::Ternary) {
+	} else if (axisPoints.type == DatapickerImage::GraphType::Ternary) {
 		for (int i = 0; i < 3; ++i) {
 			x[i] = (2*axisPoints.logicalPos[i].y() + axisPoints.logicalPos[i].z())/(2*axisPoints.ternaryScale);
-			y[i] = (sqrt(3)*axisPoints.logicalPos[i].z())/(2*axisPoints.ternaryScale);
+			y[i] = (M_SQRT3 * axisPoints.logicalPos[i].z())/(2*axisPoints.ternaryScale);
 			X[i] = axisPoints.scenePos[i].x();
 			Y[i] = axisPoints.scenePos[i].y();
 		}
@@ -86,7 +92,7 @@ bool Transform::mapTypeToCartesian(const DatapickerImage::ReferencePoints& axisP
 	return true;
 }
 
-QVector3D Transform::mapSceneToLogical(const QPointF& scenePoint, const DatapickerImage::ReferencePoints& axisPoints) {
+QVector3D Transform::mapSceneToLogical(QPointF scenePoint, const DatapickerImage::ReferencePoints& axisPoints) {
 	X[3] = scenePoint.x();
 	Y[3] = scenePoint.y();
 
@@ -123,25 +129,25 @@ QVector3D Transform::mapSceneToLogical(const QPointF& scenePoint, const Datapick
 	return QVector3D{};
 }
 
-QVector3D Transform::mapSceneLengthToLogical(const QPointF& errorSpan, const DatapickerImage::ReferencePoints& axisPoints) {
+QVector3D Transform::mapSceneLengthToLogical(QPointF errorSpan, const DatapickerImage::ReferencePoints& axisPoints) {
 	return mapSceneToLogical(errorSpan, axisPoints) - mapSceneToLogical(QPointF(0,0), axisPoints);
 }
 
-QVector3D Transform::mapCartesianToType(const QPointF& point, const DatapickerImage::ReferencePoints &axisPoints) const {
-	if (axisPoints.type == DatapickerImage::LogarithmicX) {
+QVector3D Transform::mapCartesianToType(QPointF point, const DatapickerImage::ReferencePoints &axisPoints) const {
+	if (axisPoints.type == DatapickerImage::GraphType::LogarithmicX) {
 		return QVector3D(exp(point.x()), point.y(), 0);
-	} else if (axisPoints.type == DatapickerImage::LogarithmicY) {
+	} else if (axisPoints.type == DatapickerImage::GraphType::LogarithmicY) {
 		return QVector3D(point.x(), exp(point.y()), 0);
-	} else if (axisPoints.type == DatapickerImage::PolarInDegree) {
+	} else if (axisPoints.type == DatapickerImage::GraphType::PolarInDegree) {
 		double r = sqrt(point.x()*point.x() + point.y()*point.y());
-		double angle = atan(point.y()*180/(point.x()*M_PI));
+		double angle = atan(point.y() / point.x() * M_180_PI);
 		return QVector3D(r, angle, 0);
-	} else if (axisPoints.type == DatapickerImage::PolarInRadians) {
+	} else if (axisPoints.type == DatapickerImage::GraphType::PolarInRadians) {
 		double r = sqrt(point.x()*point.x() + point.y()*point.y());
 		double angle = atan(point.y()/point.x());
 		return QVector3D(r, angle, 0);
-	} else if (axisPoints.type == DatapickerImage::Ternary) {
-		double c = (point.y()*2*axisPoints.ternaryScale)/sqrt(3);
+	} else if (axisPoints.type == DatapickerImage::GraphType::Ternary) {
+		double c = (point.y()*2*axisPoints.ternaryScale)/M_SQRT3;
 		double b = (point.x()*2*axisPoints.ternaryScale - c)/2;
 		double a = axisPoints.ternaryScale - b - c;
 		return QVector3D(a, b, c);
