@@ -34,10 +34,12 @@
 #include "backend/matrix/Matrix.h"
 
 #include <QLocalSocket>
-#include <QSerialPort>
 #include <QTimer>
 #include <QVector>
 #include <QMap>
+#ifdef HAVE_QTSERIALPORT
+#include <QSerialPort>
+#endif
 
 class QString;
 class AbstractFileFilter;
@@ -53,7 +55,7 @@ class LiveDataSource : public Spreadsheet {
 	Q_ENUMS(ReadingType)
 
 public:
-	enum SourceType {
+	enum class SourceType {
 		FileOrPipe = 0,		// regular file or pipe
 		NetworkTcpSocket,	// TCP socket
 		NetworkUdpSocket,	// UDP socket
@@ -62,12 +64,12 @@ public:
 		MQTT
 	};
 
-	enum UpdateType {
+	enum class UpdateType {
 		TimeInterval = 0,	// update periodically using given interval
 		NewData			// update when new data is available
 	};
 
-	enum ReadingType {
+	enum class ReadingType {
 		ContinuousFixed = 0,	// read continuously sampleSize number of samples (lines)
 		FromEnd,		// read sampleSize number of samples (lines) from end
 		TillEnd,		// read until the end
@@ -157,7 +159,7 @@ private:
 	QString m_localSocketName;
 	QString m_host;
 
-	AbstractFileFilter::FileType m_fileType{AbstractFileFilter::Ascii};
+	AbstractFileFilter::FileType m_fileType{AbstractFileFilter::FileType::Ascii};
 	UpdateType m_updateType;
 	SourceType m_sourceType;
 	ReadingType m_readingType;
@@ -187,7 +189,9 @@ private:
 	QLocalSocket* m_localSocket{nullptr};
 	QTcpSocket* m_tcpSocket{nullptr};
 	QUdpSocket* m_udpSocket{nullptr};
+#ifdef HAVE_QTSERIALPORT
 	QSerialPort* m_serialPort{nullptr};
+#endif
 	QIODevice* m_device{nullptr};
 	QAction* m_plotDataAction{nullptr};
 
@@ -201,7 +205,9 @@ private slots:
 
 	void localSocketError(QLocalSocket::LocalSocketError);
 	void tcpSocketError(QAbstractSocket::SocketError);
+#ifdef HAVE_QTSERIALPORT
 	void serialPortError(QSerialPort::SerialPortError);
+#endif
 };
 
 #endif
