@@ -38,14 +38,14 @@ Copyright            : (C) 2018 Stefan Gerlach (stefan.gerlach@uni.kn)
 
 \ingroup datasources
 */
-NgspiceRawBinaryFilter::NgspiceRawBinaryFilter() : AbstractFileFilter(NgspiceRawBinary), d(new NgspiceRawBinaryFilterPrivate(this)) {}
+NgspiceRawBinaryFilter::NgspiceRawBinaryFilter() : AbstractFileFilter(FileType::NgspiceRawBinary), d(new NgspiceRawBinaryFilterPrivate(this)) {}
 
 NgspiceRawBinaryFilter::~NgspiceRawBinaryFilter() = default;
 
 bool NgspiceRawBinaryFilter::isNgspiceBinaryFile(const QString& fileName) {
 	QFile file(fileName);
 	if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-		DEBUG("Failed to open the file " << fileName.toStdString());
+		DEBUG("Failed to open the file " << STDSTRING(fileName));
 		return false;
 	}
 
@@ -164,12 +164,12 @@ NgspiceRawBinaryFilterPrivate::NgspiceRawBinaryFilterPrivate(NgspiceRawBinaryFil
     reads the content of the file \c fileName to the data source \c dataSource. Uses the settings defined in the data source.
 */
 void NgspiceRawBinaryFilterPrivate::readDataFromFile(const QString& fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode importMode) {
-	DEBUG("NgspiceRawBinaryFilterPrivate::readDataFromFile(): fileName = \'" << fileName.toStdString() << "\', dataSource = "
+	DEBUG("NgspiceRawBinaryFilterPrivate::readDataFromFile(): fileName = \'" << STDSTRING(fileName) << "\', dataSource = "
 	      << dataSource << ", mode = " << ENUM_TO_STRING(AbstractFileFilter, ImportMode, importMode));
 
 	QFile file(fileName);
 	if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-		DEBUG("Failed to open the file " << fileName.toStdString());
+		DEBUG("Failed to open the file " << STDSTRING(fileName));
 		return;
 	}
 
@@ -184,11 +184,11 @@ void NgspiceRawBinaryFilterPrivate::readDataFromFile(const QString& fileName, Ab
 
 	//number of variables
 	line = file.readLine();
-	const int vars = line.right(line.length() - 15).toInt(); //remove the "No. Variables: " sub-string
+	const int vars = line.rightRef(line.length() - 15).toInt(); //remove the "No. Variables: " sub-string
 
 	//number of points
 	line = file.readLine();
-	const int points = line.right(line.length() - 12).toInt(); //remove the "No. Points: " sub-string
+	const int points = line.rightRef(line.length() - 12).toInt(); //remove the "No. Points: " sub-string
 
 	//add names of the variables
 	vectorNames.clear();
@@ -201,11 +201,11 @@ void NgspiceRawBinaryFilterPrivate::readDataFromFile(const QString& fileName, Ab
 		if (hasComplexValues) {
 			vectorNames << name + QLatin1String(" REAL");
 			vectorNames << name + QLatin1String(" IMAGINARY");
-			columnModes << AbstractColumn::Numeric;
-			columnModes << AbstractColumn::Numeric;
+			columnModes << AbstractColumn::ColumnMode::Numeric;
+			columnModes << AbstractColumn::ColumnMode::Numeric;
 		} else {
 			vectorNames << name;
-			columnModes << AbstractColumn::Numeric;
+			columnModes << AbstractColumn::ColumnMode::Numeric;
 		}
 	}
 
@@ -262,7 +262,7 @@ QVector<QStringList> NgspiceRawBinaryFilterPrivate::preview(const QString& fileN
 
 	QFile file(fileName);
 	if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-		DEBUG("Failed to open the file " << fileName.toStdString());
+		DEBUG("Failed to open the file " << STDSTRING(fileName));
 		return dataStrings;
 	}
 
@@ -277,12 +277,12 @@ QVector<QStringList> NgspiceRawBinaryFilterPrivate::preview(const QString& fileN
 
 	//number of variables
 	line = file.readLine();
-	const int vars = line.right(line.length() - 15).toInt(); //remove the "No. Variables: " sub-string
+	const int vars = line.rightRef(line.length() - 15).toInt(); //remove the "No. Variables: " sub-string
 	DEBUG("	vars = " << vars);
 
 	//number of points
 	line = file.readLine();
-	const int points = line.right(line.length() - 12).toInt(); //remove the "No. Points: " sub-string
+	const int points = line.rightRef(line.length() - 12).toInt(); //remove the "No. Points: " sub-string
 	DEBUG("	points = " << points);
 
 	//add names of the variables
@@ -296,11 +296,11 @@ QVector<QStringList> NgspiceRawBinaryFilterPrivate::preview(const QString& fileN
 		if (hasComplexValues) {
 			vectorNames << name + QLatin1String(" REAL");
 			vectorNames << name + QLatin1String(" IMAGINARY");
-			columnModes << AbstractColumn::Numeric;
-			columnModes << AbstractColumn::Numeric;
+			columnModes << AbstractColumn::ColumnMode::Numeric;
+			columnModes << AbstractColumn::ColumnMode::Numeric;
 		} else {
 			vectorNames << name;
-			columnModes << AbstractColumn::Numeric;
+			columnModes << AbstractColumn::ColumnMode::Numeric;
 		}
 	}
 
