@@ -6,7 +6,7 @@
     --------------------------------------------------------------------
     Copyright            : (C) 2008-2009 Tilman Benkert (thzs@gmx.net)
     Copyright            : (C) 2015-2017 Alexander Semke (alexander.semke@web.de)
-    Copyright            : (C) 2017-2018 Stefan Gerlach (stefan.gerlach@uni.kn)
+    Copyright            : (C) 2017-2020 Stefan Gerlach (stefan.gerlach@uni.kn)
 
  ***************************************************************************/
 
@@ -39,15 +39,14 @@
 #include "commonfrontend/matrix/MatrixView.h"
 #include "kdefrontend/spreadsheet/ExportSpreadsheetDialog.h"
 
+#include <KLocalizedString>
+#include <KConfig>
+
 #include <QHeaderView>
 #include <QPrinter>
 #include <QPrintDialog>
 #include <QPrintPreviewDialog>
 
-#include <KConfig>
-#include <KConfigGroup>
-#include <KLocalizedString>
-
 /*!
 	This class manages matrix based data (i.e., mathematically
 	a MxN matrix with M rows, N columns). This data is typically
@@ -99,7 +98,7 @@ void Matrix::init() {
 	QByteArray formatba = group.readEntry("NumericFormat", "f").toLatin1();
 	d->numericFormat = *formatba.data();
 	d->precision = group.readEntry("Precision", 3);
-	d->headerFormat = (Matrix::HeaderFormat)group.readEntry("HeaderFormat", (int)Matrix::HeaderRowsColumns);
+	d->headerFormat = (Matrix::HeaderFormat)group.readEntry("HeaderFormat", static_cast<int>(HeaderFormat::HeaderRowsColumns));
 }
 
 /*!
@@ -143,7 +142,7 @@ bool Matrix::exportView() const {
 		const QString path = dlg->path();
 		WAIT_CURSOR;
 
-		if (dlg->format() == ExportSpreadsheetDialog::LaTeX) {
+		if (dlg->format() == ExportSpreadsheetDialog::Format::LaTeX) {
 			const bool verticalHeader = dlg->matrixVerticalHeader();
 			const bool horizontalHeader = dlg->matrixHorizontalHeader();
 			const bool latexHeader = dlg->exportHeader();
@@ -152,7 +151,7 @@ bool Matrix::exportView() const {
 			const bool captions = dlg->captions();
 			m_view->exportToLaTeX(path, verticalHeader, horizontalHeader,
 				latexHeader, gridLines, entire, captions);
-		} else if (dlg->format() == ExportSpreadsheetDialog::FITS) {
+		} else if (dlg->format() == ExportSpreadsheetDialog::Format::FITS) {
 			const int exportTo = dlg->exportToFits();
 			m_view->exportToFits(path, exportTo );
 		} else {
@@ -181,7 +180,7 @@ bool Matrix::printView() {
 }
 
 bool Matrix::printPreview() const {
-	QPrintPreviewDialog* dlg = new QPrintPreviewDialog(m_view);
+	auto* dlg = new QPrintPreviewDialog(m_view);
 	connect(dlg, &QPrintPreviewDialog::paintRequested, m_view, &MatrixView::print);
 	return dlg->exec();
 }
@@ -303,18 +302,21 @@ void Matrix::removeColumns(int first, int count) {
 	if (count < 1 || first < 0 || first+count > columnCount()) return;
 	WAIT_CURSOR;
 	switch (d->mode) {
-	case AbstractColumn::Numeric:
+	case AbstractColumn::ColumnMode::Numeric:
 		exec(new MatrixRemoveColumnsCmd<double>(d, first, count));
 		break;
-	case AbstractColumn::Text:
+	case AbstractColumn::ColumnMode::Text:
 		exec(new MatrixRemoveColumnsCmd<QString>(d, first, count));
 		break;
-	case AbstractColumn::Integer:
+	case AbstractColumn::ColumnMode::Integer:
 		exec(new MatrixRemoveColumnsCmd<int>(d, first, count));
 		break;
-	case AbstractColumn::Day:
-	case AbstractColumn::Month:
-	case AbstractColumn::DateTime:
+	case AbstractColumn::ColumnMode::BigInt:
+		exec(new MatrixRemoveColumnsCmd<qint64>(d, first, count));
+		break;
+	case AbstractColumn::ColumnMode::Day:
+	case AbstractColumn::ColumnMode::Month:
+	case AbstractColumn::ColumnMode::DateTime:
 		exec(new MatrixRemoveColumnsCmd<QDateTime>(d, first, count));
 		break;
 	}
@@ -324,18 +326,21 @@ void Matrix::removeColumns(int first, int count) {
 void Matrix::clearColumn(int c) {
 	WAIT_CURSOR;
 	switch (d->mode) {
-	case AbstractColumn::Numeric:
+	case AbstractColumn::ColumnMode::Numeric:
 		exec(new MatrixClearColumnCmd<double>(d, c));
 		break;
-	case AbstractColumn::Text:
+	case AbstractColumn::ColumnMode::Text:
 		exec(new MatrixClearColumnCmd<QString>(d, c));
 		break;
-	case AbstractColumn::Integer:
+	case AbstractColumn::ColumnMode::Integer:
 		exec(new MatrixClearColumnCmd<int>(d, c));
 		break;
-	case AbstractColumn::Day:
-	case AbstractColumn::Month:
-	case AbstractColumn::DateTime:
+	case AbstractColumn::ColumnMode::BigInt:
+		exec(new MatrixClearColumnCmd<qint64>(d, c));
+		break;
+	case AbstractColumn::ColumnMode::Day:
+	case AbstractColumn::ColumnMode::Month:
+	case AbstractColumn::ColumnMode::DateTime:
 		exec(new MatrixClearColumnCmd<QDateTime>(d, c));
 		break;
 	}
@@ -358,18 +363,21 @@ void Matrix::removeRows(int first, int count) {
 	if (count < 1 || first < 0 || first+count > rowCount()) return;
 	WAIT_CURSOR;
 	switch (d->mode) {
-	case AbstractColumn::Numeric:
+	case AbstractColumn::ColumnMode::Numeric:
 		exec(new MatrixRemoveRowsCmd<double>(d, first, count));
 		break;
-	case AbstractColumn::Text:
+	case AbstractColumn::ColumnMode::Text:
 		exec(new MatrixRemoveRowsCmd<QString>(d, first, count));
 		break;
-	case AbstractColumn::Integer:
+	case AbstractColumn::ColumnMode::Integer:
 		exec(new MatrixRemoveRowsCmd<int>(d, first, count));
 		break;
-	case AbstractColumn::Day:
-	case AbstractColumn::Month:
-	case AbstractColumn::DateTime:
+	case AbstractColumn::ColumnMode::BigInt:
+		exec(new MatrixRemoveRowsCmd<qint64>(d, first, count));
+		break;
+	case AbstractColumn::ColumnMode::Day:
+	case AbstractColumn::ColumnMode::Month:
+	case AbstractColumn::ColumnMode::DateTime:
 		exec(new MatrixRemoveRowsCmd<QDateTime>(d, first, count));
 		break;
 	}
@@ -378,21 +386,25 @@ void Matrix::removeRows(int first, int count) {
 
 void Matrix::clearRow(int r) {
 	switch (d->mode) {
-	case AbstractColumn::Numeric:
+	case AbstractColumn::ColumnMode::Numeric:
 		for (int c = 0; c < columnCount(); ++c)
 			exec(new MatrixSetCellValueCmd<double>(d, r, c, 0.0));
 		break;
-	case AbstractColumn::Text:
+	case AbstractColumn::ColumnMode::Text:
 		for (int c = 0; c < columnCount(); ++c)
 			exec(new MatrixSetCellValueCmd<QString>(d, r, c, QString()));
 		break;
-	case AbstractColumn::Integer:
+	case AbstractColumn::ColumnMode::Integer:
 		for (int c = 0; c < columnCount(); ++c)
 			exec(new MatrixSetCellValueCmd<int>(d, r, c, 0));
 		break;
-	case AbstractColumn::Day:
-	case AbstractColumn::Month:
-	case AbstractColumn::DateTime:
+	case AbstractColumn::ColumnMode::BigInt:
+		for (int c = 0; c < columnCount(); ++c)
+			exec(new MatrixSetCellValueCmd<qint64>(d, r, c, 0));
+		break;
+	case AbstractColumn::ColumnMode::Day:
+	case AbstractColumn::ColumnMode::Month:
+	case AbstractColumn::ColumnMode::DateTime:
 		for (int c = 0; c < columnCount(); ++c)
 			exec(new MatrixSetCellValueCmd<QDateTime>(d, r, c, QDateTime()));
 		break;
@@ -406,24 +418,27 @@ T Matrix::cell(int row, int col) const {
 }
 template double Matrix::cell<double>(int row, int col) const;
 template int Matrix::cell<int>(int row, int col) const;
+template qint64 Matrix::cell<qint64>(int row, int col) const;
 template QDateTime Matrix::cell<QDateTime>(int row, int col) const;
 template QString Matrix::cell<QString>(int row, int col) const;
 
 //! Return the text displayed in the given cell (needs explicit instantiation)
 template <typename T>
 QString Matrix::text(int row, int col) {
-	return QLocale().toString(cell<T>(row,col));
+	SET_NUMBER_LOCALE
+	return numberLocale.toString(cell<T>(row,col));
 }
-// special cases
 template <>
 QString Matrix::text<double>(int row, int col) {
-	return QLocale().toString(cell<double>(row,col), d->numericFormat, d->precision);
+	SET_NUMBER_LOCALE
+	return numberLocale.toString(cell<double>(row,col), d->numericFormat, d->precision);
 }
 template <>
 QString Matrix::text<QString>(int row, int col) {
 	return cell<QString>(row,col);
 }
 template QString Matrix::text<int>(int row, int col);
+template QString Matrix::text<qint64>(int row, int col);
 template QString Matrix::text<QDateTime>(int row, int col);
 
 //! Set the value of the cell (needs explicit instantiation)
@@ -435,23 +450,27 @@ void Matrix::setCell(int row, int col, T value) {
 }
 template void Matrix::setCell<double>(int row, int col, double value);
 template void Matrix::setCell<int>(int row, int col, int value);
-template void Matrix::setCell<QDateTime>(int row, int col, QDateTime value);
+template void Matrix::setCell<qint64>(int row, int col, qint64 value);
 template void Matrix::setCell<QString>(int row, int col, QString value);
+template void Matrix::setCell<QDateTime>(int row, int col, QDateTime value);
 
 void Matrix::clearCell(int row, int col) {
 	switch (d->mode) {
-	case AbstractColumn::Numeric:
+	case AbstractColumn::ColumnMode::Numeric:
 		exec(new MatrixSetCellValueCmd<double>(d, row, col, 0.0));
 		break;
-	case AbstractColumn::Text:
+	case AbstractColumn::ColumnMode::Text:
 		exec(new MatrixSetCellValueCmd<QString>(d, row, col, QString()));
 		break;
-	case AbstractColumn::Integer:
+	case AbstractColumn::ColumnMode::Integer:
 		exec(new MatrixSetCellValueCmd<int>(d, row, col, 0));
 		break;
-	case AbstractColumn::Day:
-	case AbstractColumn::Month:
-	case AbstractColumn::DateTime:
+	case AbstractColumn::ColumnMode::BigInt:
+		exec(new MatrixSetCellValueCmd<qint64>(d, row, col, 0));
+		break;
+	case AbstractColumn::ColumnMode::Day:
+	case AbstractColumn::ColumnMode::Month:
+	case AbstractColumn::ColumnMode::DateTime:
 		exec(new MatrixSetCellValueCmd<QDateTime>(d, row, col, QDateTime()));
 		break;
 	}
@@ -496,21 +515,25 @@ void Matrix::copy(Matrix* other) {
 
 	d->suppressDataChange = true;
 	switch (d->mode) {
-	case AbstractColumn::Numeric:
+	case AbstractColumn::ColumnMode::Numeric:
 		for (int i = 0; i < columns; i++)
 			setColumnCells(i, 0, rows-1, other->columnCells<double>(i, 0, rows-1));
 		break;
-	case AbstractColumn::Text:
+	case AbstractColumn::ColumnMode::Text:
 		for (int i = 0; i < columns; i++)
 			setColumnCells(i, 0, rows-1, other->columnCells<QString>(i, 0, rows-1));
 		break;
-	case AbstractColumn::Integer:
+	case AbstractColumn::ColumnMode::Integer:
 		for (int i = 0; i < columns; i++)
 			setColumnCells(i, 0, rows-1, other->columnCells<int>(i, 0, rows-1));
 		break;
-	case AbstractColumn::Day:
-	case AbstractColumn::Month:
-	case AbstractColumn::DateTime:
+	case AbstractColumn::ColumnMode::BigInt:
+		for (int i = 0; i < columns; i++)
+			setColumnCells(i, 0, rows-1, other->columnCells<qint64>(i, 0, rows-1));
+		break;
+	case AbstractColumn::ColumnMode::Day:
+	case AbstractColumn::ColumnMode::Month:
+	case AbstractColumn::ColumnMode::DateTime:
 		for (int i = 0; i < columns; i++)
 			setColumnCells(i, 0, rows-1, other->columnCells<QDateTime>(i, 0, rows-1));
 		break;
@@ -625,21 +648,25 @@ void Matrix::setData(void* data) {
 	bool isEmpty = false;
 
 	switch (d->mode) {
-	case AbstractColumn::Numeric:
+	case AbstractColumn::ColumnMode::Numeric:
 		if (static_cast<QVector<QVector<double>>*>(data)->isEmpty())
 			isEmpty = true;
 		break;
-	case AbstractColumn::Text:
+	case AbstractColumn::ColumnMode::Text:
 		if (static_cast<QVector<QVector<QString>>*>(data)->isEmpty())
 			isEmpty = true;
 		break;
-	case AbstractColumn::Integer:
+	case AbstractColumn::ColumnMode::Integer:
 		if (static_cast<QVector<QVector<int>>*>(data)->isEmpty())
 			isEmpty = true;
 		break;
-	case AbstractColumn::Day:
-	case AbstractColumn::Month:
-	case AbstractColumn::DateTime:
+	case AbstractColumn::ColumnMode::BigInt:
+		if (static_cast<QVector<QVector<qint64>>*>(data)->isEmpty())
+			isEmpty = true;
+		break;
+	case AbstractColumn::ColumnMode::Day:
+	case AbstractColumn::ColumnMode::Month:
+	case AbstractColumn::ColumnMode::DateTime:
 		if (static_cast<QVector<QVector<QDateTime>>*>(data)->isEmpty())
 			isEmpty = true;
 		break;
@@ -657,18 +684,21 @@ void Matrix::clear() {
 	WAIT_CURSOR;
 	beginMacro(i18n("%1: clear", name()));
 	switch (d->mode) {
-	case AbstractColumn::Numeric:
+	case AbstractColumn::ColumnMode::Numeric:
 		exec(new MatrixClearCmd<double>(d));
 		break;
-	case AbstractColumn::Text:
+	case AbstractColumn::ColumnMode::Text:
 		exec(new MatrixClearCmd<QString>(d));
 		break;
-	case AbstractColumn::Integer:
+	case AbstractColumn::ColumnMode::Integer:
 		exec(new MatrixClearCmd<int>(d));
 		break;
-	case AbstractColumn::Day:
-	case AbstractColumn::Month:
-	case AbstractColumn::DateTime:
+	case AbstractColumn::ColumnMode::BigInt:
+		exec(new MatrixClearCmd<qint64>(d));
+		break;
+	case AbstractColumn::ColumnMode::Day:
+	case AbstractColumn::ColumnMode::Month:
+	case AbstractColumn::ColumnMode::DateTime:
 		exec(new MatrixClearCmd<QDateTime>(d));
 		break;
 	}
@@ -679,18 +709,21 @@ void Matrix::clear() {
 void Matrix::transpose() {
 	WAIT_CURSOR;
 	switch (d->mode) {
-	case AbstractColumn::Numeric:
+	case AbstractColumn::ColumnMode::Numeric:
 		exec(new MatrixTransposeCmd<double>(d));
 		break;
-	case AbstractColumn::Text:
+	case AbstractColumn::ColumnMode::Text:
 		exec(new MatrixTransposeCmd<QString>(d));
 		break;
-	case AbstractColumn::Integer:
+	case AbstractColumn::ColumnMode::Integer:
 		exec(new MatrixTransposeCmd<int>(d));
 		break;
-	case AbstractColumn::Day:
-	case AbstractColumn::Month:
-	case AbstractColumn::DateTime:
+	case AbstractColumn::ColumnMode::BigInt:
+		exec(new MatrixTransposeCmd<qint64>(d));
+		break;
+	case AbstractColumn::ColumnMode::Day:
+	case AbstractColumn::ColumnMode::Month:
+	case AbstractColumn::ColumnMode::DateTime:
 		exec(new MatrixTransposeCmd<QDateTime>(d));
 		break;
 	}
@@ -700,18 +733,21 @@ void Matrix::transpose() {
 void Matrix::mirrorHorizontally() {
 	WAIT_CURSOR;
 	switch (d->mode) {
-	case AbstractColumn::Numeric:
+	case AbstractColumn::ColumnMode::Numeric:
 		exec(new MatrixMirrorHorizontallyCmd<double>(d));
 		break;
-	case AbstractColumn::Text:
+	case AbstractColumn::ColumnMode::Text:
 		exec(new MatrixMirrorHorizontallyCmd<QString>(d));
 		break;
-	case AbstractColumn::Integer:
+	case AbstractColumn::ColumnMode::Integer:
 		exec(new MatrixMirrorHorizontallyCmd<int>(d));
 		break;
-	case AbstractColumn::Day:
-	case AbstractColumn::Month:
-	case AbstractColumn::DateTime:
+	case AbstractColumn::ColumnMode::BigInt:
+		exec(new MatrixMirrorHorizontallyCmd<qint64>(d));
+		break;
+	case AbstractColumn::ColumnMode::Day:
+	case AbstractColumn::ColumnMode::Month:
+	case AbstractColumn::ColumnMode::DateTime:
 		exec(new MatrixMirrorHorizontallyCmd<QDateTime>(d));
 		break;
 	}
@@ -721,18 +757,21 @@ void Matrix::mirrorHorizontally() {
 void Matrix::mirrorVertically() {
 	WAIT_CURSOR;
 	switch (d->mode) {
-	case AbstractColumn::Numeric:
+	case AbstractColumn::ColumnMode::Numeric:
 		exec(new MatrixMirrorVerticallyCmd<double>(d));
 		break;
-	case AbstractColumn::Text:
+	case AbstractColumn::ColumnMode::Text:
 		exec(new MatrixMirrorVerticallyCmd<QString>(d));
 		break;
-	case AbstractColumn::Integer:
+	case AbstractColumn::ColumnMode::Integer:
 		exec(new MatrixMirrorVerticallyCmd<int>(d));
 		break;
-	case AbstractColumn::Day:
-	case AbstractColumn::Month:
-	case AbstractColumn::DateTime:
+	case AbstractColumn::ColumnMode::BigInt:
+		exec(new MatrixMirrorVerticallyCmd<qint64>(d));
+		break;
+	case AbstractColumn::ColumnMode::Day:
+	case AbstractColumn::ColumnMode::Month:
+	case AbstractColumn::ColumnMode::DateTime:
 		exec(new MatrixMirrorVerticallyCmd<QDateTime>(d));
 		break;
 	}
@@ -747,38 +786,44 @@ MatrixPrivate::MatrixPrivate(Matrix* owner, const AbstractColumn::ColumnMode m)
 		: q(owner), data(nullptr), mode(m), rowCount(0), columnCount(0), suppressDataChange(false) {
 
 	switch (mode) {
-	case AbstractColumn::Numeric:
+	case AbstractColumn::ColumnMode::Numeric:
 		data = new QVector<QVector<double>>();
 		break;
-	case AbstractColumn::Text:
+	case AbstractColumn::ColumnMode::Text:
 		data = new QVector<QVector<QString>>();
 		break;
-	case AbstractColumn::Month:
-	case AbstractColumn::Day:
-	case AbstractColumn::DateTime:
-		data = new QVector<QVector<QDateTime>>();
-		break;
-	case AbstractColumn::Integer:
+	case AbstractColumn::ColumnMode::Integer:
 		data = new QVector<QVector<int>>();
 		break;
+	case AbstractColumn::ColumnMode::BigInt:
+		data = new QVector<QVector<qint64>>();
+		break;
+	case AbstractColumn::ColumnMode::Month:
+	case AbstractColumn::ColumnMode::Day:
+	case AbstractColumn::ColumnMode::DateTime:
+		data = new QVector<QVector<QDateTime>>();
+		break;
 	}
 }
 
 MatrixPrivate::~MatrixPrivate() {
 	if (data) {
 		switch (mode) {
-		case AbstractColumn::Numeric:
+		case AbstractColumn::ColumnMode::Numeric:
 			delete static_cast<QVector<QVector<double>>*>(data);
 			break;
-		case AbstractColumn::Text:
+		case AbstractColumn::ColumnMode::Text:
 			delete static_cast<QVector<QVector<QString>>*>(data);
 			break;
-		case AbstractColumn::Integer:
+		case AbstractColumn::ColumnMode::Integer:
 			delete static_cast<QVector<QVector<int>>*>(data);
 			break;
-		case AbstractColumn::Day:
-		case AbstractColumn::Month:
-		case AbstractColumn::DateTime:
+		case AbstractColumn::ColumnMode::BigInt:
+			delete static_cast<QVector<QVector<qint64>>*>(data);
+			break;
+		case AbstractColumn::ColumnMode::Day:
+		case AbstractColumn::ColumnMode::Month:
+		case AbstractColumn::ColumnMode::DateTime:
 			delete static_cast<QVector<QVector<QDateTime>>*>(data);
 			break;
 		}
@@ -790,7 +835,7 @@ void MatrixPrivate::updateViewHeader() {
 }
 
 /*!
-	Insert \count columns before column number \c before
+	Insert \p count columns before column number \c before
 */
 void MatrixPrivate::insertColumns(int before, int count) {
 	Q_ASSERT(before >= 0);
@@ -798,27 +843,33 @@ void MatrixPrivate::insertColumns(int before, int count) {
 
 	emit q->columnsAboutToBeInserted(before, count);
 	switch (mode) {
-	case AbstractColumn::Numeric:
+	case AbstractColumn::ColumnMode::Numeric:
 		for (int i = 0; i < count; i++) {
 			static_cast<QVector<QVector<double>>*>(data)->insert(before+i, QVector<double>(rowCount));
 			columnWidths.insert(before+i, 0);
 		}
 		break;
-	case AbstractColumn::Text:
+	case AbstractColumn::ColumnMode::Text:
 		for (int i = 0; i < count; i++) {
 			static_cast<QVector<QVector<QString>>*>(data)->insert(before+i, QVector<QString>(rowCount));
 			columnWidths.insert(before+i, 0);
 		}
 		break;
-	case AbstractColumn::Integer:
+	case AbstractColumn::ColumnMode::Integer:
 		for (int i = 0; i < count; i++) {
 			static_cast<QVector<QVector<int>>*>(data)->insert(before+i, QVector<int>(rowCount));
 			columnWidths.insert(before+i, 0);
 		}
 		break;
-	case AbstractColumn::Day:
-	case AbstractColumn::Month:
-	case AbstractColumn::DateTime:
+	case AbstractColumn::ColumnMode::BigInt:
+		for (int i = 0; i < count; i++) {
+			static_cast<QVector<QVector<qint64>>*>(data)->insert(before+i, QVector<qint64>(rowCount));
+			columnWidths.insert(before+i, 0);
+		}
+		break;
+	case AbstractColumn::ColumnMode::Day:
+	case AbstractColumn::ColumnMode::Month:
+	case AbstractColumn::ColumnMode::DateTime:
 		for (int i = 0; i < count; i++) {
 			static_cast<QVector<QVector<QDateTime>>*>(data)->insert(before+i, QVector<QDateTime>(rowCount));
 			columnWidths.insert(before+i, 0);
@@ -839,18 +890,21 @@ void MatrixPrivate::removeColumns(int first, int count) {
 	Q_ASSERT(first + count <= columnCount);
 
 	switch (mode) {
-	case AbstractColumn::Numeric:
+	case AbstractColumn::ColumnMode::Numeric:
 		(static_cast<QVector<QVector<double>>*>(data))->remove(first, count);
 		break;
-	case AbstractColumn::Text:
+	case AbstractColumn::ColumnMode::Text:
 		(static_cast<QVector<QVector<QString>>*>(data))->remove(first, count);
 		break;
-	case AbstractColumn::Integer:
+	case AbstractColumn::ColumnMode::Integer:
 		(static_cast<QVector<QVector<int>>*>(data))->remove(first, count);
 		break;
-	case AbstractColumn::Day:
-	case AbstractColumn::Month:
-	case AbstractColumn::DateTime:
+	case AbstractColumn::ColumnMode::BigInt:
+		(static_cast<QVector<QVector<qint64>>*>(data))->remove(first, count);
+		break;
+	case AbstractColumn::ColumnMode::Day:
+	case AbstractColumn::ColumnMode::Month:
+	case AbstractColumn::ColumnMode::DateTime:
 		(static_cast<QVector<QVector<QDateTime>>*>(data))->remove(first, count);
 		break;
 	}
@@ -870,24 +924,29 @@ void MatrixPrivate::insertRows(int before, int count) {
 	Q_ASSERT(before <= rowCount);
 
 	switch (mode) {
-	case AbstractColumn::Numeric:
+	case AbstractColumn::ColumnMode::Numeric:
 		for (int col = 0; col < columnCount; col++)
 			for (int i = 0; i < count; i++)
 				(static_cast<QVector<QVector<double>>*>(data))->operator[](col).insert(before+i, 0.0);
 		break;
-	case AbstractColumn::Text:
+	case AbstractColumn::ColumnMode::Text:
 		for (int col = 0; col < columnCount; col++)
 			for (int i = 0; i < count; i++)
 				(static_cast<QVector<QVector<QString>>*>(data))->operator[](col).insert(before+i, QString());
 		break;
-	case AbstractColumn::Integer:
+	case AbstractColumn::ColumnMode::Integer:
 		for (int col = 0; col < columnCount; col++)
 			for (int i = 0; i < count; i++)
 				(static_cast<QVector<QVector<int>>*>(data))->operator[](col).insert(before+i, 0);
 		break;
-	case AbstractColumn::Day:
-	case AbstractColumn::Month:
-	case AbstractColumn::DateTime:
+	case AbstractColumn::ColumnMode::BigInt:
+		for (int col = 0; col < columnCount; col++)
+			for (int i = 0; i < count; i++)
+				(static_cast<QVector<QVector<qint64>>*>(data))->operator[](col).insert(before+i, 0);
+		break;
+	case AbstractColumn::ColumnMode::Day:
+	case AbstractColumn::ColumnMode::Month:
+	case AbstractColumn::ColumnMode::DateTime:
 		for (int col = 0; col < columnCount; col++)
 			for (int i = 0; i < count; i++)
 				(static_cast<QVector<QVector<QDateTime>>*>(data))->operator[](col).insert(before+i, QDateTime());
@@ -909,21 +968,25 @@ void MatrixPrivate::removeRows(int first, int count) {
 	Q_ASSERT(first+count <= rowCount);
 
 	switch (mode) {
-	case AbstractColumn::Numeric:
+	case AbstractColumn::ColumnMode::Numeric:
 		for (int col = 0; col < columnCount; col++)
 			(static_cast<QVector<QVector<double>>*>(data))->operator[](col).remove(first, count);
 		break;
-	case AbstractColumn::Text:
+	case AbstractColumn::ColumnMode::Text:
 		for (int col = 0; col < columnCount; col++)
 			(static_cast<QVector<QVector<QString>>*>(data))->operator[](col).remove(first, count);
 		break;
-	case AbstractColumn::Integer:
+	case AbstractColumn::ColumnMode::Integer:
 		for (int col = 0; col < columnCount; col++)
 			(static_cast<QVector<QVector<int>>*>(data))->operator[](col).remove(first, count);
 		break;
-	case AbstractColumn::Day:
-	case AbstractColumn::Month:
-	case AbstractColumn::DateTime:
+	case AbstractColumn::ColumnMode::BigInt:
+		for (int col = 0; col < columnCount; col++)
+			(static_cast<QVector<QVector<qint64>>*>(data))->operator[](col).remove(first, count);
+		break;
+	case AbstractColumn::ColumnMode::Day:
+	case AbstractColumn::ColumnMode::Month:
+	case AbstractColumn::ColumnMode::DateTime:
 		for (int col = 0; col < columnCount; col++)
 			(static_cast<QVector<QVector<QDateTime>>*>(data))->operator[](col).remove(first, count);
 		break;
@@ -939,18 +1002,21 @@ void MatrixPrivate::removeRows(int first, int count) {
 //! Fill column with zeroes
 void MatrixPrivate::clearColumn(int col) {
 	switch (mode) {
-	case AbstractColumn::Numeric:
+	case AbstractColumn::ColumnMode::Numeric:
 		static_cast<QVector<QVector<double>>*>(data)->operator[](col).fill(0.0);
 		break;
-	case AbstractColumn::Text:
+	case AbstractColumn::ColumnMode::Text:
 		static_cast<QVector<QVector<QString>>*>(data)->operator[](col).fill(QString());
 		break;
-	case AbstractColumn::Integer:
+	case AbstractColumn::ColumnMode::Integer:
 		static_cast<QVector<QVector<int>>*>(data)->operator[](col).fill(0);
 		break;
-	case AbstractColumn::Day:
-	case AbstractColumn::Month:
-	case AbstractColumn::DateTime:
+	case AbstractColumn::ColumnMode::BigInt:
+		static_cast<QVector<QVector<qint64>>*>(data)->operator[](col).fill(0);
+		break;
+	case AbstractColumn::ColumnMode::Day:
+	case AbstractColumn::ColumnMode::Month:
+	case AbstractColumn::ColumnMode::DateTime:
 		static_cast<QVector<QVector<QDateTime>>*>(data)->operator[](col).fill(QDateTime());
 		break;
 	}
@@ -975,8 +1041,8 @@ void Matrix::save(QXmlStreamWriter* writer) const {
 
 	//format
 	writer->writeStartElement("format");
-	writer->writeAttribute("mode", QString::number(d->mode));
-	writer->writeAttribute("headerFormat", QString::number(d->headerFormat));
+	writer->writeAttribute("mode", QString::number(static_cast<int>(d->mode)));
+	writer->writeAttribute("headerFormat", QString::number(static_cast<int>(d->headerFormat)));
 	writer->writeAttribute("numericFormat", QString(QChar(d->numericFormat)));
 	writer->writeAttribute("precision", QString::number(d->precision));
 	writer->writeEndElement();
@@ -1006,9 +1072,9 @@ void Matrix::save(QXmlStreamWriter* writer) const {
 	writer->writeEndElement();
 
 	//columns
-	DEBUG("	mode = " << d->mode);
+	DEBUG("	mode = " << static_cast<int>(d->mode));
 	switch (d->mode) {
-	case AbstractColumn::Numeric:
+	case AbstractColumn::ColumnMode::Numeric:
 		size = d->rowCount*sizeof(double);
 		for (int i = 0; i < d->columnCount; ++i) {
 			data = reinterpret_cast<const char*>(static_cast<QVector<QVector<double>>*>(d->data)->at(i).constData());
@@ -1017,7 +1083,7 @@ void Matrix::save(QXmlStreamWriter* writer) const {
 			writer->writeEndElement();
 		}
 		break;
-	case AbstractColumn::Text:
+	case AbstractColumn::ColumnMode::Text:
 		size = d->rowCount*sizeof(QString);
 		for (int i = 0; i < d->columnCount; ++i) {
 			QDEBUG("	string: " << static_cast<QVector<QVector<QString>>*>(d->data)->at(i));
@@ -1027,7 +1093,7 @@ void Matrix::save(QXmlStreamWriter* writer) const {
 			writer->writeEndElement();
 		}
 		break;
-	case AbstractColumn::Integer:
+	case AbstractColumn::ColumnMode::Integer:
 		size = d->rowCount*sizeof(int);
 		for (int i = 0; i < d->columnCount; ++i) {
 			data = reinterpret_cast<const char*>(static_cast<QVector<QVector<int>>*>(d->data)->at(i).constData());
@@ -1036,9 +1102,18 @@ void Matrix::save(QXmlStreamWriter* writer) const {
 			writer->writeEndElement();
 		}
 		break;
-	case AbstractColumn::Day:
-	case AbstractColumn::Month:
-	case AbstractColumn::DateTime:
+	case AbstractColumn::ColumnMode::BigInt:
+		size = d->rowCount*sizeof(qint64);
+		for (int i = 0; i < d->columnCount; ++i) {
+			data = reinterpret_cast<const char*>(static_cast<QVector<QVector<qint64>>*>(d->data)->at(i).constData());
+			writer->writeStartElement("column");
+			writer->writeCharacters(QByteArray::fromRawData(data, size).toBase64());
+			writer->writeEndElement();
+		}
+		break;
+	case AbstractColumn::ColumnMode::Day:
+	case AbstractColumn::ColumnMode::Month:
+	case AbstractColumn::ColumnMode::DateTime:
 		size = d->rowCount*sizeof(QDateTime);
 		for (int i = 0; i < d->columnCount; ++i) {
 			data = reinterpret_cast<const char*>(static_cast<QVector<QVector<QDateTime>>*>(d->data)->at(i).constData());
@@ -1163,7 +1238,7 @@ bool Matrix::load(XmlStreamReader* reader, bool preview) {
 			QByteArray bytes = QByteArray::fromBase64(content.toLatin1());
 
 			switch (d->mode) {
-			case AbstractColumn::Numeric: {
+			case AbstractColumn::ColumnMode::Numeric: {
 				int count = bytes.size()/sizeof(double);
 				QVector<double> column;
 				column.resize(count);
@@ -1171,7 +1246,7 @@ bool Matrix::load(XmlStreamReader* reader, bool preview) {
 				static_cast<QVector<QVector<double>>*>(d->data)->append(column);
 				break;
 			}
-			case AbstractColumn::Text: {
+			case AbstractColumn::ColumnMode::Text: {
 				int count = bytes.size()/sizeof(char);
 				QVector<QString> column;
 				column.resize(count);
@@ -1181,7 +1256,7 @@ bool Matrix::load(XmlStreamReader* reader, bool preview) {
 				static_cast<QVector<QVector<QString>>*>(d->data)->append(column);
 				break;
 			}
-			case AbstractColumn::Integer: {
+			case AbstractColumn::ColumnMode::Integer: {
 				int count = bytes.size()/sizeof(int);
 				QVector<int> column;
 				column.resize(count);
@@ -1189,9 +1264,17 @@ bool Matrix::load(XmlStreamReader* reader, bool preview) {
 				static_cast<QVector<QVector<int>>*>(d->data)->append(column);
 				break;
 			}
-			case AbstractColumn::Day:
-			case AbstractColumn::Month:
-			case AbstractColumn::DateTime: {
+			case AbstractColumn::ColumnMode::BigInt: {
+				int count = bytes.size()/sizeof(qint64);
+				QVector<qint64> column;
+				column.resize(count);
+				memcpy(column.data(), bytes.data(), count*sizeof(qint64));
+				static_cast<QVector<QVector<qint64>>*>(d->data)->append(column);
+				break;
+			}
+			case AbstractColumn::ColumnMode::Day:
+			case AbstractColumn::ColumnMode::Month:
+			case AbstractColumn::ColumnMode::DateTime: {
 				int count = bytes.size()/sizeof(QDateTime);
 				QVector<QDateTime> column;
 				column.resize(count);
@@ -1211,21 +1294,13 @@ bool Matrix::load(XmlStreamReader* reader, bool preview) {
 	return true;
 }
 
-void Matrix::registerShortcuts() {
-	m_view->registerShortcuts();
-}
-
-void Matrix::unregisterShortcuts() {
-	m_view->unregisterShortcuts();
-}
-
 //##############################################################################
 //########################  Data Import  #######################################
 //##############################################################################
 int Matrix::prepareImport(std::vector<void*>& dataContainer, AbstractFileFilter::ImportMode mode,
 	int actualRows, int actualCols, QStringList colNameList, QVector<AbstractColumn::ColumnMode> columnMode) {
 	QDEBUG("prepareImport() rows =" << actualRows << " cols =" << actualCols);
-	QDEBUG("	column modes = " << columnMode);
+	//QDEBUG("	column modes = " << columnMode);
 	Q_UNUSED(colNameList);
 	int columnOffset = 0;
 	setUndoAware(false);
@@ -1233,7 +1308,7 @@ int Matrix::prepareImport(std::vector<void*>& dataContainer, AbstractFileFilter:
 	setSuppressDataChangedSignal(true);
 
 	// resize the matrix
-	if (mode == AbstractFileFilter::Replace) {
+	if (mode == AbstractFileFilter::ImportMode::Replace) {
 		clear();
 		setDimensions(actualRows, actualCols);
 	} else {
@@ -1246,39 +1321,47 @@ int Matrix::prepareImport(std::vector<void*>& dataContainer, AbstractFileFilter:
 	// data() returns a void* which is a pointer to a matrix of any data type (see ColumnPrivate.cpp)
 	dataContainer.resize(actualCols);
 	switch (columnMode[0]) {	// only columnMode[0] is used
-	case AbstractColumn::Numeric:
+	case AbstractColumn::ColumnMode::Numeric:
 		for (int n = 0; n < actualCols; n++) {
 			QVector<double>* vector = &(static_cast<QVector<QVector<double>>*>(data())->operator[](n));
 			vector->resize(actualRows);
 			dataContainer[n] = static_cast<void*>(vector);
 		}
-		d->mode = AbstractColumn::Numeric;
+		d->mode = AbstractColumn::ColumnMode::Numeric;
 		break;
-	case AbstractColumn::Integer:
+	case AbstractColumn::ColumnMode::Integer:
 		for (int n = 0; n < actualCols; n++) {
 			QVector<int>* vector = &(static_cast<QVector<QVector<int>>*>(data())->operator[](n));
 			vector->resize(actualRows);
 			dataContainer[n] = static_cast<void*>(vector);
 		}
-		d->mode = AbstractColumn::Integer;
+		d->mode = AbstractColumn::ColumnMode::Integer;
 		break;
-	case AbstractColumn::Text:
+	case AbstractColumn::ColumnMode::BigInt:
+		for (int n = 0; n < actualCols; n++) {
+			QVector<qint64>* vector = &(static_cast<QVector<QVector<qint64>>*>(data())->operator[](n));
+			vector->resize(actualRows);
+			dataContainer[n] = static_cast<void*>(vector);
+		}
+		d->mode = AbstractColumn::ColumnMode::BigInt;
+		break;
+	case AbstractColumn::ColumnMode::Text:
 		for (int n = 0; n < actualCols; n++) {
 			QVector<QString>* vector = &(static_cast<QVector<QVector<QString>>*>(data())->operator[](n));
 			vector->resize(actualRows);
 			dataContainer[n] = static_cast<void*>(vector);
 		}
-		d->mode = AbstractColumn::Text;
+		d->mode = AbstractColumn::ColumnMode::Text;
 		break;
-	case AbstractColumn::Day:
-	case AbstractColumn::Month:
-	case AbstractColumn::DateTime:
+	case AbstractColumn::ColumnMode::Day:
+	case AbstractColumn::ColumnMode::Month:
+	case AbstractColumn::ColumnMode::DateTime:
 		for (int n = 0; n < actualCols; n++) {
 			QVector<QDateTime>* vector = &(static_cast<QVector<QVector<QDateTime>>*>(data())->operator[](n));
 			vector->resize(actualRows);
 			dataContainer[n] = static_cast<void*>(vector);
 		}
-		d->mode = AbstractColumn::DateTime;
+		d->mode = AbstractColumn::ColumnMode::DateTime;
 		break;
 	}
 
