@@ -973,14 +973,14 @@ int Spreadsheet::resize(AbstractFileFilter::ImportMode mode, QStringList colName
 		for (int n = 0; n < cols; n++ ) {
 			newColumn = new Column(colNameList.at(n), AbstractColumn::ColumnMode::Numeric);
 			newColumn->setUndoAware(false);
-			addChildFast(newColumn);
+			addChild(newColumn);
 		}
 	} else if (mode == AbstractFileFilter::ImportMode::Prepend) {
 		Column* firstColumn = child<Column>(0);
 		for (int n = 0; n < cols; n++ ) {
 			newColumn = new Column(colNameList.at(n), AbstractColumn::ColumnMode::Numeric);
 			newColumn->setUndoAware(false);
-			insertChildBeforeFast(newColumn, firstColumn);
+			insertChildBefore(newColumn, firstColumn);
 		}
 	} else if (mode == AbstractFileFilter::ImportMode::Replace) {
 		//replace completely the previous content of the data source with the content to be imported.
@@ -996,7 +996,7 @@ int Spreadsheet::resize(AbstractFileFilter::ImportMode mode, QStringList colName
 			for (int i = columns; i < cols; i++) {
 				newColumn = new Column(colNameList.at(i), AbstractColumn::ColumnMode::Numeric);
 				newColumn->setUndoAware(false);
-				addChildFast(newColumn);
+				addChildFast(newColumn); //in the replace mode, we can skip checking the uniqueness of the names and use the "fast" method
 			}
 		}
 
@@ -1090,5 +1090,9 @@ void Spreadsheet::finalizeImport(int columnOffset, int startColumn, int endColum
 	if (m_partView != nullptr && m_view != nullptr)
 		m_view->resizeHeader();
 
+	//row count most probably changed after the import, notify the dock widget.
+	//no need to notify about the column cound change, this is done already because of add/removeChild signals
+	rowCountChanged(rowCount());
+
 	DEBUG("Spreadsheet::finalizeImport() DONE");
 }
