@@ -50,12 +50,12 @@ public:
 	explicit Worksheet(const QString& name, bool loading = false);
 	~Worksheet() override;
 
-	enum Unit {Millimeter, Centimeter, Inch, Point};
-	enum Layout {NoLayout, VerticalLayout, HorizontalLayout, GridLayout};
-	enum CartesianPlotActionMode {ApplyActionToSelection, ApplyActionToAll};
+	enum class Unit {Millimeter, Centimeter, Inch, Point};
+	enum class Layout {NoLayout, VerticalLayout, HorizontalLayout, GridLayout};
+	enum class CartesianPlotActionMode {ApplyActionToSelection, ApplyActionToAll};
 
-	static float convertToSceneUnits(const float value, const Worksheet::Unit unit);
-	static float convertFromSceneUnits(const float value, const Worksheet::Unit unit);
+	static double convertToSceneUnits(const double value, const Worksheet::Unit unit);
+	static double convertFromSceneUnits(const double value, const Worksheet::Unit unit);
 
 	QIcon icon() const override;
 	QMenu* createContextMenu() override;
@@ -80,6 +80,7 @@ public:
 	void setSelectedInView(const bool);
 	void deleteAspectFromGraphicsItem(const QGraphicsItem*);
 	void setIsClosing();
+	void suppressSelectionChangedEvent(bool);
 
 	CartesianPlotActionMode cartesianPlotActionMode();
 	void setCartesianPlotActionMode(CartesianPlotActionMode mode);
@@ -88,11 +89,11 @@ public:
 	void setPlotsLocked(bool);
 	bool plotsLocked();
 	int getPlotCount();
-	WorksheetElement* getPlot(int index);
+	CartesianPlot* getPlot(int index);
 	TreeModel* cursorModel();
 
-	void cursorModelPlotAdded(QString name);
-	void cursorModelPlotRemoved(QString name);
+	void cursorModelPlotAdded(const QString& name);
+	void cursorModelPlotRemoved(const QString& name);
 
 	BASIC_D_ACCESSOR_DECL(float, backgroundOpacity, BackgroundOpacity)
 	BASIC_D_ACCESSOR_DECL(PlotArea::BackgroundType, backgroundType, BackgroundType)
@@ -137,7 +138,7 @@ public slots:
 	void cartesianPlotMouseModeChangedSlot(CartesianPlot::MouseMode);
 
 	// slots needed by the cursor
-	void updateCurveBackground(QPen pen, QString curveName);
+	void updateCurveBackground(const QPen&, const QString& curveName);
 	void updateCompleteCursorTreeModel();
 	void cursorPosChanged(int cursorNumber, double xPos);
 	void curveAdded(const XYCurve* curve);
@@ -168,6 +169,8 @@ signals:
 	void requestUpdate();
 	void useViewSizeRequested();
 	void cartesianPlotMouseModeChanged(CartesianPlot::MouseMode);
+	void showCursorDock(TreeModel*, QVector<CartesianPlot*>);
+	void propertiesExplorerRequested();
 
 	void backgroundTypeChanged(PlotArea::BackgroundType);
 	void backgroundColorStyleChanged(PlotArea::BackgroundColorStyle);
@@ -189,7 +192,6 @@ signals:
 	void layoutRowCountChanged(int);
 	void layoutColumnCountChanged(int);
 	void themeChanged(const QString&);
-	void showCursorDock(TreeModel*, QVector<CartesianPlot*>);
 };
 
 #endif
