@@ -41,6 +41,9 @@ public:
 
 	float horizontalPadding; //horiz. offset between the plot area and the area defining the coordinate system, in scene units
 	float verticalPadding; //vert. offset between the plot area and the area defining the coordinate system, in scene units
+	double rightPadding;
+	double bottomPadding;
+	bool symmetricPadding;
 };
 
 #endif
