@@ -3,7 +3,7 @@
     Project              : LabPlot
     Description          : Symbol
     --------------------------------------------------------------------
-    Copyright            : (C) 2015 Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2015-2020 Alexander Semke (alexander.semke@web.de)
 
  ***************************************************************************/
 
@@ -35,10 +35,11 @@ class QString;
 
 class Symbol {
 public:
-	enum Style {NoSymbols, Circle, Square, EquilateralTriangle, RightTriangle, Bar, PeakedBar,
+	enum class Style {NoSymbols, Circle, Square, EquilateralTriangle, RightTriangle, Bar, PeakedBar,
 			SkewedBar, Diamond, Lozenge, Tie, TinyTie, Plus, Boomerang, SmallBoomerang,
 			Star4, Star5, Line, Cross};
 
+	static int stylesCount();
 	static QPainterPath pathFromStyle(Symbol::Style);
 	static QString nameFromStyle(Symbol::Style);
 };
