@@ -69,8 +69,8 @@ void XYEquationCurve::init() {
 	addChildFast(d->yColumn);
 
 	//TODO: read from the saved settings for XYEquationCurve?
-	d->lineType = XYCurve::Line;
-	d->symbolsStyle = Symbol::NoSymbols;
+	d->lineType = XYCurve::LineType::Line;
+	d->symbolsStyle = Symbol::Style::NoSymbols;
 
 	setUndoAware(false);
 	suppressRetransform(true);
@@ -115,8 +115,8 @@ void XYEquationCurve::setEquationData(const XYEquationCurve::EquationData& equat
 //######################### Private implementation #############################
 //##############################################################################
 XYEquationCurvePrivate::XYEquationCurvePrivate(XYEquationCurve* owner) : XYCurvePrivate(owner),
-	xColumn(new Column("x", AbstractColumn::Numeric)),
-	yColumn(new Column("y", AbstractColumn::Numeric)),
+	xColumn(new Column("x", AbstractColumn::ColumnMode::Numeric)),
+	yColumn(new Column("y", AbstractColumn::ColumnMode::Numeric)),
 	xVector(static_cast<QVector<double>* >(xColumn->data())),
 	yVector(static_cast<QVector<double>* >(yColumn->data())),
 	q(owner)  {
@@ -148,13 +148,13 @@ void XYEquationCurvePrivate::recalculate() {
 
 	ExpressionParser* parser = ExpressionParser::getInstance();
 	bool rc = false;
-	if (equationData.type == XYEquationCurve::Cartesian) {
+	if (equationData.type == XYEquationCurve::EquationType::Cartesian) {
 		rc = parser->evaluateCartesian( equationData.expression1, equationData.min, equationData.max,
 						equationData.count, xVector, yVector );
-	} else if (equationData.type == XYEquationCurve::Polar) {
+	} else if (equationData.type == XYEquationCurve::EquationType::Polar) {
 		rc = parser->evaluatePolar( equationData.expression1, equationData.min, equationData.max,
 						equationData.count, xVector, yVector );
-	} else if (equationData.type == XYEquationCurve::Parametric) {
+	} else if (equationData.type == XYEquationCurve::EquationType::Parametric) {
 		rc = parser->evaluateParametric(equationData.expression1, equationData.expression2,
 						equationData.min, equationData.max, equationData.count,
 						xVector, yVector);
@@ -183,7 +183,7 @@ void XYEquationCurve::save(QXmlStreamWriter* writer) const{
 
 	//write xy-equationCurve specific information
 	writer->writeStartElement("equationData");
-	writer->writeAttribute( "type", QString::number(d->equationData.type) );
+	writer->writeAttribute( "type", QString::number(static_cast<int>(d->equationData.type)) );
 	writer->writeAttribute( "expression1", d->equationData.expression1 );
 	writer->writeAttribute( "expression2", d->equationData.expression2 );
 	writer->writeAttribute( "min", d->equationData.min);
