@@ -1645,8 +1645,9 @@ void WorksheetView::exportToFile(const QString& path, const ExportFormat format,
 	} else
 		sourceRect = scene()->sceneRect();
 
-	//print
-	if (format == ExportFormat::PDF) {
+	//save
+	switch (format) {
+	case ExportFormat::PDF: {
 		QPrinter printer(QPrinter::HighResolution);
 		printer.setOutputFormat(QPrinter::PdfFormat);
 
@@ -1664,7 +1665,9 @@ void WorksheetView::exportToFile(const QString& path, const ExportFormat format,
 		painter.begin(&printer);
 		exportPaint(&painter, targetRect, sourceRect, background);
 		painter.end();
-	} else if (format == ExportFormat::SVG) {
+		break;
+	}
+	case ExportFormat::SVG: {
 		QSvgGenerator generator;
 		generator.setFileName(path);
 // 		if (!generator.isValid()) {
@@ -1684,9 +1687,14 @@ void WorksheetView::exportToFile(const QString& path, const ExportFormat format,
 		painter.begin(&generator);
 		exportPaint(&painter, targetRect, sourceRect, background);
 		painter.end();
-	} else {
-		//PNG
-		//TODO add all formats supported by Qt in QImage
+		break;
+	}
+	case  ExportFormat::PNG:
+	case  ExportFormat::JPG:
+	case  ExportFormat::BMP:
+	case  ExportFormat::PPM:
+	case  ExportFormat::XBM:
+	case  ExportFormat::XPM: {
 		int w = Worksheet::convertFromSceneUnits(sourceRect.width(), Worksheet::Unit::Millimeter);
 		int h = Worksheet::convertFromSceneUnits(sourceRect.height(), Worksheet::Unit::Millimeter);
 		w = w*resolution/25.4;
@@ -1702,7 +1710,30 @@ void WorksheetView::exportToFile(const QString& path, const ExportFormat format,
 		painter.end();
 
 		if (!path.isEmpty()) {
-			bool rc = image.save(path, "PNG");
+			bool rc{false};
+			switch (format) {
+			case  ExportFormat::PNG:
+				rc = image.save(path, "PNG");
+				break;
+			case  ExportFormat::JPG:
+				rc = image.save(path, "JPG");
+				break;
+			case  ExportFormat::BMP:
+				rc = image.save(path, "BMP");
+				break;
+			case  ExportFormat::PPM:
+				rc = image.save(path, "PPM");
+				break;
+			case  ExportFormat::XBM:
+				rc = image.save(path, "XBM");
+				break;
+			case  ExportFormat::XPM:
+				rc = image.save(path, "XPM");
+				break;
+			case ExportFormat::PDF:
+			case ExportFormat::SVG:
+				break;
+			}
 			if (!rc) {
 				RESET_CURSOR;
 				QMessageBox::critical(nullptr, i18n("Failed to export"), i18n("Failed to write to '%1'. Please check the path.", path));
@@ -1710,6 +1741,7 @@ void WorksheetView::exportToFile(const QString& path, const ExportFormat format,
 		} else
 			QApplication::clipboard()->setImage(image, QClipboard::Clipboard);
 	}
+	}
 }
 
 void WorksheetView::exportToClipboard() {
