@@ -2,7 +2,7 @@
     File                 : SettingsDialog.cpp
     Project              : LabPlot
     --------------------------------------------------------------------
-    Copyright            : (C) 2008-2019 by Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2008-2020 Alexander Semke (alexander.semke@web.de)
     Description          : application settings dialog
 
  ***************************************************************************/
@@ -29,6 +29,9 @@
 
 #include "MainWin.h"
 #include "SettingsGeneralPage.h"
+#include "SettingsDatasetsPage.h"
+// #include "SettingsWelcomePage.h"
+#include "SettingsSpreadsheetPage.h"
 #include "SettingsWorksheetPage.h"
 
 #include <QPushButton>
@@ -41,6 +44,10 @@
 #include <KWindowConfig>
 #include <KI18n/KLocalizedString>
 
+#ifdef HAVE_KUSERFEEDBACK
+#include <KUserFeedback/FeedbackConfigWidget>
+#endif
+
 /**
  * \brief Settings dialog for Labplot.
  *
@@ -67,6 +74,30 @@ SettingsDialog::SettingsDialog(QWidget* parent) : KPageDialog(parent) {
 	worksheetFrame->setIcon(QIcon::fromTheme(QLatin1String("labplot-worksheet")));
 	connect(m_worksheetPage, &SettingsWorksheetPage::settingsChanged, this, &SettingsDialog::changed);
 
+	m_spreadsheetPage = new SettingsSpreadsheetPage(this);
+	KPageWidgetItem* spreadsheetFrame = addPage(m_spreadsheetPage, i18n("Spreadsheet"));
+	spreadsheetFrame->setIcon(QIcon::fromTheme(QLatin1String("labplot-spreadsheet")));
+	connect(m_spreadsheetPage, &SettingsSpreadsheetPage::settingsChanged, this, &SettingsDialog::changed);
+
+	m_datasetsPage = new SettingsDatasetsPage(this);
+	KPageWidgetItem* datasetsFrame = addPage(m_datasetsPage, i18n("Datasets"));
+	datasetsFrame->setIcon(QIcon::fromTheme(QLatin1String("database-index")));
+
+// 	m_welcomePage = new SettingsWelcomePage(this);
+// 	KPageWidgetItem* welcomeFrame = addPage(m_welcomePage, i18n("Welcome Screen"));
+// 	welcomeFrame->setIcon(QIcon::fromTheme(QLatin1String("database-index")));
+// 	connect(m_welcomePage, &SettingsWelcomePage::resetWelcomeScreen, this, &SettingsDialog::resetWelcomeScreen);
+
+#ifdef HAVE_KUSERFEEDBACK
+	auto* mainWin = static_cast<MainWin*>(parent);
+	m_userFeedbackWidget = new KUserFeedback::FeedbackConfigWidget(this);
+	m_userFeedbackWidget->setFeedbackProvider(&mainWin->userFeedbackProvider());
+	connect(m_userFeedbackWidget, &KUserFeedback::FeedbackConfigWidget::configurationChanged, this, &SettingsDialog::changed);
+
+	KPageWidgetItem* userFeedBackFrame = addPage(m_userFeedbackWidget, i18n("User Feedback"));
+	userFeedBackFrame->setIcon(QIcon::fromTheme(QLatin1String("preferences-desktop-locale")));
+#endif
+
 	//restore saved settings if available
 	create(); // ensure there's a window created
 	KConfigGroup conf(KSharedConfig::openConfig(), "SettingsDialog");
@@ -109,7 +140,15 @@ void SettingsDialog::applySettings() {
 	m_changed = false;
 	m_generalPage->applySettings();
 	m_worksheetPage->applySettings();
+	m_spreadsheetPage->applySettings();
 	KSharedConfig::openConfig()->sync();
+
+#ifdef HAVE_KUSERFEEDBACK
+	auto* mainWin = static_cast<MainWin*>(parent());
+	mainWin->userFeedbackProvider().setTelemetryMode(m_userFeedbackWidget->telemetryMode());
+	mainWin->userFeedbackProvider().setSurveyInterval(m_userFeedbackWidget->surveyInterval());
+#endif
+
 	emit settingsChanged();
 }
 
@@ -117,4 +156,5 @@ void SettingsDialog::restoreDefaults() {
 	m_changed = false;
 	m_generalPage->restoreDefaults();
 	m_worksheetPage->restoreDefaults();
+	m_spreadsheetPage->restoreDefaults();
 }
