@@ -28,6 +28,7 @@ Copyright            : (C) 2017-2018 Alexander Semke (alexander.semke@web.de)
 
 #include "DatabaseManagerWidget.h"
 #include "backend/lib/macros.h"
+#include "kdefrontend/GuiTools.h"
 
 #include <KConfig>
 #include <KConfigGroup>
@@ -152,7 +153,7 @@ void DatabaseManagerWidget::nameChanged(const QString& name) {
 	}
 
 	if (unique) {
-		ui.leName->setStyleSheet(QString());
+		GuiTools::highlight(ui.leName, false);
 		if (auto item = ui.lwConnections->currentItem()) {
 			item->setText(name);
 
@@ -162,7 +163,7 @@ void DatabaseManagerWidget::nameChanged(const QString& name) {
 			}
 		}
 	} else
-		ui.leName->setStyleSheet("QLineEdit{background: red;}");
+		GuiTools::highlight(ui.leName, true);
 }
 
 void DatabaseManagerWidget::driverChanged() {
@@ -235,7 +236,7 @@ void DatabaseManagerWidget::selectFile() {
 	if (path.isEmpty())
 		return; //cancel was clicked in the file-dialog
 
-	int pos = path.lastIndexOf(QDir::separator());
+	int pos = path.lastIndexOf(QLatin1String("/"));
 	if (pos != -1) {
 		QString newDir = path.left(pos);
 		if (newDir != dir)
@@ -268,20 +269,18 @@ void DatabaseManagerWidget::portChanged() {
 }
 
 void DatabaseManagerWidget::databaseNameChanged() {
-	QString dbName = ui.leDatabase->text().simplified();
+	QString dbName{ui.leDatabase->text().simplified()};
 	if (isFileDB(ui.cbDriver->currentText())) {
-#ifndef HAVE_WINDOWS
-		// make relative path
-		if ( !dbName.isEmpty() && dbName.at(0) != QDir::separator())
-			dbName = QDir::homePath() + QDir::separator() + dbName;
+#ifdef HAVE_WINDOWS
+		if (!dbName.isEmpty() && dbName.at(1) != QLatin1String(":"))
+#else
+		if (!dbName.isEmpty() && dbName.at(0) != QLatin1String("/"))
 #endif
+			dbName = QDir::homePath() + QLatin1String("/") + dbName;
 
 		if (!dbName.isEmpty()) {
 			bool fileExists = QFile::exists(dbName);
-			if (fileExists)
-				ui.leDatabase->setStyleSheet(QString());
-			else
-				ui.leDatabase->setStyleSheet(QStringLiteral("QLineEdit{background:red;}"));
+			GuiTools::highlight(ui.leName, !fileExists);
 		} else {
 			ui.leDatabase->setStyleSheet(QString());
 		}
@@ -290,7 +289,7 @@ void DatabaseManagerWidget::databaseNameChanged() {
 	}
 
 	//don't allow to try to connect if no database name was provided
-	ui.bTestConnection->setEnabled( !dbName.isEmpty() );
+	ui.bTestConnection->setEnabled(!dbName.isEmpty());
 
 	if (m_initializing)
 		return;
@@ -507,12 +506,13 @@ void DatabaseManagerWidget::testConnection() {
 
 	//don't allow to test the connection for file DBs if the file doesn't exist
 	if (isFileDB(ui.cbDriver->currentText())) {
-		QString fileName = ui.leDatabase->text();
-#ifndef HAVE_WINDOWS
-		// make relative path
-		if ( !fileName.isEmpty() && fileName.at(0) != QDir::separator())
-			fileName = QDir::homePath() + QDir::separator() + fileName;
+		QString fileName{ui.leDatabase->text()};
+#ifdef HAVE_WINDOWS
+		if ( !fileName.isEmpty() && fileName.at(1) != QLatin1String(":"))
+#else
+		if ( !fileName.isEmpty() && fileName.at(0) != QLatin1String("/"))
 #endif
+			fileName = QDir::homePath() + QLatin1String("/") + fileName;
 
 		if (!QFile::exists(fileName)) {
 			KMessageBox::error(this, i18n("Failed to connect to the database '%1'.", m_current_connection->dbName),
@@ -559,9 +559,9 @@ void DatabaseManagerWidget::testConnection() {
 
 /*!
  * returns \c true if \c driver is for file databases like Sqlite or for ODBC datasources.
- * returns \false otherwise.
+ * returns \c false otherwise.
  * for file databases and for ODBC/ODBC3, only the name of the database/ODBC-datasource is required.
- * used to show/hide relevant connection settins widgets.
+ * used to show/hide relevant connection settings widgets.
  */
 bool DatabaseManagerWidget::isFileDB(const QString& driver) {
 	//QSQLITE, QSQLITE3
