@@ -60,7 +60,7 @@ void fillTree(QTreeWidgetItem* node, const ROOTFilter::Directory& dir)
 QHash<QStringList, QVector<QStringList> > findLeaves(
 	QTreeWidgetItem* node,
 	ROOTFilter* filter,
-	const QString& fileName, QStringList path = QStringList{}
+	const QString& fileName, const QStringList& path = QStringList{}
 ) {
 	QHash<QStringList, QVector<QStringList> > leaves;
 	if (node->childCount() > 0) {
@@ -140,7 +140,7 @@ void ROOTOptionsWidget::rootObjectSelectionChanged() {
 				if (l.count() > 1) {
 					QString index(l.back());
 					if (index.at(0) == '[' && index.at(index.size() - 1) == ']') {
-						size_t elements = index.mid(1, index.length() - 2).toUInt(&ok);
+						size_t elements = index.midRef(1, index.length() - 2).toUInt(&ok);
 						if (ok) {
 							leaf->setFlags(Qt::ItemIsEnabled);
 							QStringList elname({l.at(l.count() - 2), QString()});
