@@ -4,7 +4,7 @@
     Description          : widget for Histogram properties
     --------------------------------------------------------------------
     Copyright            : (C) 2016 Anu Mittal (anu22mittal@gmail.com)
-    Copyright            : (C) 2018 by Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2018-2021 by Alexander Semke (alexander.semke@web.de)
 
  ***************************************************************************/
 
@@ -129,6 +129,8 @@ HistogramDock::HistogramDock(QWidget* parent) : BaseDock(parent), cbDataColumn(n
 	connect( ui.chkAutoBinRanges, &QCheckBox::stateChanged, this, &HistogramDock::autoBinRangesChanged );
 	connect( ui.leBinRangesMin, &QLineEdit::textChanged, this, &HistogramDock::binRangesMinChanged );
 	connect( ui.leBinRangesMax, &QLineEdit::textChanged, this, &HistogramDock::binRangesMaxChanged );
+	connect(ui.dteBinRangesMin, &QDateTimeEdit::dateTimeChanged, this, &HistogramDock::binRangesMinDateTimeChanged);
+	connect(ui.dteBinRangesMax, &QDateTimeEdit::dateTimeChanged, this, &HistogramDock::binRangesMaxDateTimeChanged);
 
 	//Line
 	connect(ui.cbLineType, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &HistogramDock::lineTypeChanged);
@@ -160,8 +162,8 @@ HistogramDock::HistogramDock(QWidget* parent) : BaseDock(parent), cbDataColumn(n
 	connect(ui.cbValuesNumericFormat, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &HistogramDock::valuesNumericFormatChanged);
 	connect(ui.sbValuesPrecision, QOverload<int>::of(&QSpinBox::valueChanged), this, &HistogramDock::valuesPrecisionChanged);
 	connect(ui.cbValuesDateTimeFormat, &QComboBox::currentTextChanged, this, &HistogramDock::valuesDateTimeFormatChanged);
-	connect( ui.leValuesPrefix, SIGNAL(returnPressed()), this, SLOT(valuesPrefixChanged()) );
-	connect( ui.leValuesSuffix, SIGNAL(returnPressed()), this, SLOT(valuesSuffixChanged()) );
+	connect(ui.leValuesPrefix, &QLineEdit::textChanged, this, &HistogramDock::valuesPrefixChanged);
+	connect(ui.leValuesSuffix, &QLineEdit::textChanged, this, &HistogramDock::valuesSuffixChanged);
 	connect( ui.kfrValuesFont, SIGNAL(fontSelected(QFont)), this, SLOT(valuesFontChanged(QFont)) );
 	connect( ui.kcbValuesColor, SIGNAL(changed(QColor)), this, SLOT(valuesColorChanged(QColor)) );
 
@@ -172,7 +174,7 @@ HistogramDock::HistogramDock(QWidget* parent) : BaseDock(parent), cbDataColumn(n
 	connect( ui.cbFillingImageStyle, SIGNAL(currentIndexChanged(int)), this, SLOT(fillingImageStyleChanged(int)) );
 	connect( ui.cbFillingBrushStyle, SIGNAL(currentIndexChanged(int)), this, SLOT(fillingBrushStyleChanged(int)) );
 	connect( ui.bFillingOpen, SIGNAL(clicked(bool)), this, SLOT(selectFile()));
-	connect( ui.leFillingFileName, SIGNAL(returnPressed()), this, SLOT(fileNameChanged()) );
+	connect(ui.leFillingFileName, &QLineEdit::textChanged, this, &HistogramDock::fileNameChanged);
 	connect( ui.leFillingFileName, SIGNAL(textChanged(QString)), this, SLOT(fileNameChanged()) );
 	connect( ui.kcbFillingFirstColor, SIGNAL(changed(QColor)), this, SLOT(fillingFirstColorChanged(QColor)) );
 	connect( ui.kcbFillingSecondColor, SIGNAL(changed(QColor)), this, SLOT(fillingSecondColorChanged(QColor)) );
@@ -382,7 +384,6 @@ void HistogramDock::setCurves(QList<Histogram*> list) {
 
 		this->setModelIndexFromColumn(cbDataColumn, m_curve->dataColumn());
 		this->setModelIndexFromColumn(cbValuesColumn, m_curve->valuesColumn());
-
 		ui.leName->setText(m_curve->name());
 		ui.leComment->setText(m_curve->comment());
 	} else {
@@ -393,7 +394,6 @@ void HistogramDock::setCurves(QList<Histogram*> list) {
 
 		ui.lXColumn->setEnabled(false);
 		cbDataColumn->setEnabled(false);
-
 		cbDataColumn->setCurrentModelIndex(QModelIndex());
 		cbValuesColumn->setCurrentModelIndex(QModelIndex());
 
@@ -415,6 +415,28 @@ void HistogramDock::setCurves(QList<Histogram*> list) {
 	ui.leBinRangesMax->setText( numberLocale.toString(m_curve->binRangesMax()) );
 	ui.chkVisible->setChecked( m_curve->isVisible() );
 
+	//handle numeric vs. datetime widgets
+	//TODO: we need to react on range format changes in the plot in general,
+	//add signal-slot connection for this
+	const auto* plot = static_cast<const CartesianPlot*>(m_curve->parent(AspectType::CartesianPlot));
+	ui.dteBinRangesMin->setDisplayFormat(plot->xRangeDateTimeFormat());
+	ui.dteBinRangesMax->setDisplayFormat(plot->xRangeDateTimeFormat());
+	ui.dteBinRangesMin->setDateTime(QDateTime::fromMSecsSinceEpoch(m_curve->binRangesMin()));
+	ui.dteBinRangesMax->setDateTime(QDateTime::fromMSecsSinceEpoch(m_curve->binRangesMax()));
+
+	bool numeric = (plot->xRangeFormat() == CartesianPlot::RangeFormat::Numeric);
+
+	ui.lBinRangesMin->setVisible(numeric);
+	ui.lBinRangesMax->setVisible(numeric);
+	ui.leBinRangesMin->setVisible(numeric);
+	ui.leBinRangesMax->setVisible(numeric);
+
+	ui.lBinRangesMinDateTime->setVisible(!numeric);
+	ui.dteBinRangesMin->setVisible(!numeric);
+	ui.lBinRangesMaxDateTime->setVisible(!numeric);
+	ui.dteBinRangesMax->setVisible(!numeric);
+
+	//load the remaining properties
 	KConfig config(QString(), KConfig::SimpleConfig);
 	loadConfig(config);
 
@@ -460,6 +482,7 @@ void HistogramDock::setCurves(QList<Histogram*> list) {
 	connect(m_curve, &Histogram::valuesColorChanged, this, &HistogramDock::curveValuesColorChanged);
 
 	//Filling-Tab
+	connect( m_curve, &Histogram::fillingEnabledChanged, this, &HistogramDock::curveFillingEnabledChanged);
 	connect( m_curve, &Histogram::fillingTypeChanged, this, &HistogramDock::curveFillingTypeChanged);
 	connect( m_curve, &Histogram::fillingColorStyleChanged, this, &HistogramDock::curveFillingColorStyleChanged);
 	connect( m_curve, &Histogram::fillingImageStyleChanged, this, &HistogramDock::curveFillingImageStyleChanged);
@@ -595,6 +618,8 @@ void HistogramDock::autoBinRangesChanged(int state) {
 	bool checked = (state == Qt::Checked);
 	ui.leBinRangesMin->setEnabled(!checked);
 	ui.leBinRangesMax->setEnabled(!checked);
+	ui.dteBinRangesMin->setEnabled(!checked);
+	ui.dteBinRangesMax->setEnabled(!checked);
 
 	if (m_initializing)
 		return;
@@ -631,6 +656,24 @@ void HistogramDock::binRangesMaxChanged(const QString& value) {
 	}
 }
 
+void HistogramDock::binRangesMinDateTimeChanged(const QDateTime& dateTime) {
+	if (m_initializing)
+		return;
+
+	quint64 min = dateTime.toMSecsSinceEpoch();
+	for (auto* hist : m_curvesList)
+		hist->setBinRangesMin(min);
+}
+
+void HistogramDock::binRangesMaxDateTimeChanged(const QDateTime& dateTime) {
+	if (m_initializing)
+		return;
+
+	quint64 max = dateTime.toMSecsSinceEpoch();
+	for (auto* hist : m_curvesList)
+		hist->setBinRangesMax(max);
+}
+
 //Line tab
 void HistogramDock::lineTypeChanged(int index) {
 	auto lineType = Histogram::LineType(index);
@@ -1400,6 +1443,7 @@ void HistogramDock::curveBinRangesMinChanged(double value) {
 	const Lock lock(m_initializing);
 	SET_NUMBER_LOCALE
 	ui.leBinRangesMin->setText(numberLocale.toString(value));
+	ui.dteBinRangesMin->setDateTime(QDateTime::fromMSecsSinceEpoch(value));
 }
 
 void HistogramDock::curveBinRangesMaxChanged(double value) {
@@ -1407,6 +1451,7 @@ void HistogramDock::curveBinRangesMaxChanged(double value) {
 	const Lock lock(m_initializing);
 	SET_NUMBER_LOCALE
 	ui.leBinRangesMax->setText(numberLocale.toString(value));
+	ui.dteBinRangesMax->setDateTime(QDateTime::fromMSecsSinceEpoch(value));
 }
 
 //Line-Tab
@@ -1670,6 +1715,7 @@ void HistogramDock::loadConfig(KConfig& config) {
 	ui.kcbFillingFirstColor->setColor( group.readEntry("FillingFirstColor", m_curve->fillingFirstColor()) );
 	ui.kcbFillingSecondColor->setColor( group.readEntry("FillingSecondColor", m_curve->fillingSecondColor()) );
 	ui.sbFillingOpacity->setValue( round(group.readEntry("FillingOpacity", m_curve->fillingOpacity())*100.0) );
+	fillingEnabledChanged(ui.chkFillingEnabled->isChecked()); //update the box filling widgets
 
 	//Error bars
 	ui.cbErrorType->setCurrentIndex( group.readEntry("ErrorType", (int) m_curve->errorType()) );
