@@ -4,7 +4,7 @@
     Description          : widget for project properties
     --------------------------------------------------------------------
     Copyright            : (C) 2012-2013 by Stefan Gerlach (stefan.gerlach@uni-konstanz.de)
-    Copyright            : (C) 2013 Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2013-2020 Alexander Semke (alexander.semke@web.de)
 
  ***************************************************************************/
 
@@ -40,7 +40,7 @@
   \ingroup kdefrontend
 */
 
-ProjectDock::ProjectDock(QWidget *parent): BaseDock(parent) {
+ProjectDock::ProjectDock(QWidget* parent) : BaseDock(parent) {
 	ui.setupUi(this);
 	m_leName = ui.leName;
 	// leComment = ui.tbComment; // not a qlineedit
@@ -50,8 +50,8 @@ ProjectDock::ProjectDock(QWidget *parent): BaseDock(parent) {
 	connect(ui.leAuthor, &QLineEdit::textChanged, this, &ProjectDock::authorChanged);
 	connect(ui.tbComment, &QTextBrowser::textChanged, this, &ProjectDock::commentChanged);
 
-	auto* templateHandler = new TemplateHandler(this, TemplateHandler::Worksheet);
-	ui.verticalLayout->addWidget(templateHandler, 0, nullptr);
+	auto* templateHandler = new TemplateHandler(this, TemplateHandler::ClassName::Worksheet);
+	ui.verticalLayout->addWidget(templateHandler);
 	templateHandler->show();
 	connect(templateHandler, &TemplateHandler::loadConfigRequested, this, &ProjectDock::loadConfig);
 	connect(templateHandler, &TemplateHandler::saveConfigRequested, this, &ProjectDock::saveConfig);
@@ -59,10 +59,11 @@ ProjectDock::ProjectDock(QWidget *parent): BaseDock(parent) {
 	this->retranslateUi();
 }
 
-void ProjectDock::setProject(Project *project) {
-	m_initializing = true;
+void ProjectDock::setProject(Project* project) {
 	m_project = project;
 	m_aspect = project;
+
+	m_initializing = true;
 	ui.leFileName->setText(project->fileName());
 	ui.leName->setStyleSheet("");
 	ui.leName->setToolTip("");
@@ -75,6 +76,7 @@ void ProjectDock::setProject(Project *project) {
 	loadConfig(config);
 
 	connect(m_project, &Project::aspectDescriptionChanged, this, &ProjectDock::projectDescriptionChanged);
+	connect(m_project, &Project::authorChanged, this, &ProjectDock::projectAuthorChanged);
 
 	m_initializing = false;
 }
@@ -85,11 +87,11 @@ void ProjectDock::setProject(Project *project) {
 void ProjectDock::retranslateUi() {
 }
 
-void ProjectDock::authorChanged(const QString& author) {
+void ProjectDock::authorChanged() {
 	if (m_initializing)
 		return;
 
-	m_project->setAuthor(author);
+	m_project->setAuthor(ui.leAuthor->text());
 }
 
 void ProjectDock::commentChanged() {
@@ -108,13 +110,17 @@ void ProjectDock::projectDescriptionChanged(const AbstractAspect* aspect) {
 
 	m_initializing = true;
 	if (aspect->name() != ui.leName->text())
-			ui.leName->setText(aspect->name());
+		ui.leName->setText(aspect->name());
 	else if (aspect->comment() != ui.tbComment->toPlainText())
-			ui.tbComment->setText(aspect->comment());
+		ui.tbComment->setText(aspect->comment());
 
 	m_initializing = false;
 }
 
+void ProjectDock::projectAuthorChanged(const QString& author) {
+	Lock lock(m_initializing);
+	ui.leAuthor->setText(author);
+}
 //*************************************************************
 //************************* Settings **************************
 //*************************************************************
