@@ -56,7 +56,7 @@ SpreadsheetDock::SpreadsheetDock(QWidget* parent) : BaseDock(parent) {
 	connect(ui.sbRowCount, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &SpreadsheetDock::rowCountChanged);
 	connect(ui.cbShowComments, &QCheckBox::stateChanged, this, &SpreadsheetDock::commentsShownChanged);
 
-	auto* templateHandler = new TemplateHandler(this, TemplateHandler::Spreadsheet);
+	auto* templateHandler = new TemplateHandler(this, TemplateHandler::ClassName::Spreadsheet);
 	ui.gridLayout->addWidget(templateHandler, 11, 0, 1, 4);
 	templateHandler->show();
 	connect(templateHandler, &TemplateHandler::loadConfigRequested, this, &SpreadsheetDock::loadConfigFromTemplate);
@@ -155,7 +155,7 @@ void SpreadsheetDock::commentsShownChanged(int state) {
 		return;
 
 	for (auto* spreadsheet : m_spreadsheetList)
-		qobject_cast<SpreadsheetView*>(spreadsheet->view())->showComments(state);
+		static_cast<SpreadsheetView*>(spreadsheet->view())->showComments(state);
 }
 
 //*************************************************************
@@ -199,14 +199,14 @@ void SpreadsheetDock::load() {
 	ui.sbColumnCount->setValue(m_spreadsheet->columnCount());
 	ui.sbRowCount->setValue(m_spreadsheet->rowCount());
 
-	auto* view = qobject_cast<SpreadsheetView*>(m_spreadsheet->view());
+	auto* view = static_cast<SpreadsheetView*>(m_spreadsheet->view());
 	ui.cbShowComments->setChecked(view->areCommentsShown());
 }
 
 void SpreadsheetDock::loadConfigFromTemplate(KConfig& config) {
 	//extract the name of the template from the file name
 	QString name;
-	const int index = config.name().lastIndexOf(QDir::separator());
+	const int index = config.name().lastIndexOf(QLatin1String("/"));
 	if (index != -1)
 		name = config.name().right(config.name().size() - index - 1);
 	else
@@ -232,7 +232,7 @@ void SpreadsheetDock::loadConfig(KConfig& config) {
 	ui.sbColumnCount->setValue(group.readEntry("ColumnCount", m_spreadsheet->columnCount()));
 	ui.sbRowCount->setValue(group.readEntry("RowCount", m_spreadsheet->rowCount()));
 
-	auto* view = qobject_cast<SpreadsheetView*>(m_spreadsheet->view());
+	auto* view = static_cast<SpreadsheetView*>(m_spreadsheet->view());
 	ui.cbShowComments->setChecked(group.readEntry("ShowComments", view->areCommentsShown()));
 }
 
