@@ -54,6 +54,7 @@ private:
 
 	XYSmoothCurve* m_smoothCurve{nullptr};
 	XYSmoothCurve::SmoothData m_smoothData;
+	bool m_dateTimeRange{false};
 
 protected:
 	void setModel() override;
@@ -66,14 +67,16 @@ private slots:
 	void xDataColumnChanged(const QModelIndex&);
 	void yDataColumnChanged(const QModelIndex&);
 	void autoRangeChanged();
-	void xRangeMinChanged();
-	void xRangeMaxChanged();
-	void typeChanged();
-	void pointsChanged();
-	void weightChanged();
-	void percentileChanged();
-	void orderChanged();
-	void modeChanged();
+	void xRangeMinChanged(double);
+	void xRangeMaxChanged(double);
+	void xRangeMinDateTimeChanged(const QDateTime&);
+	void xRangeMaxDateTimeChanged(const QDateTime&);
+	void typeChanged(int);
+	void pointsChanged(int);
+	void weightChanged(int);
+	void percentileChanged(double);
+	void orderChanged(int);
+	void modeChanged(int);
 	void valueChanged();
 
 	void recalculateClicked();
@@ -88,7 +91,7 @@ private slots:
 	void curveYDataColumnChanged(const AbstractColumn*);
 	void curveSmoothDataChanged(const XYSmoothCurve::SmoothData&);
 	void dataChanged();
-
+	void curveVisibilityChanged(bool);
 };
 
 #endif
