@@ -31,10 +31,10 @@
 #include "backend/worksheet/Worksheet.h"
 #include "kdefrontend/GuiTools.h"
 
-#include <QPainter>
-
 #include <KLocalizedString>
 
+#include <QPainter>
+
 #include <cmath>
 
 DatapickerCurveWidget::DatapickerCurveWidget(QWidget* parent) : BaseDock(parent) {
@@ -57,6 +57,8 @@ DatapickerCurveWidget::DatapickerCurveWidget(QWidget* parent) : BaseDock(parent)
 	ui.lYErrorType->setToolTip(info);
 	ui.cbYErrorType->setToolTip(info);
 
+	DatapickerCurveWidget::updateLocale();
+
 	connect(ui.leName, &QLineEdit::textChanged, this, &DatapickerCurveWidget::nameChanged);
 	connect(ui.leComment, &QLineEdit::textChanged, this, &DatapickerCurveWidget::commentChanged);
 	connect(ui.cbXErrorType, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
@@ -181,13 +183,20 @@ void DatapickerCurveWidget::hideErrorBarWidgets(bool on) {
 	ui.lErrorBarSize->setVisible(!on);
 }
 
+void DatapickerCurveWidget::updateLocale() {
+	SET_NUMBER_LOCALE
+	ui.sbSize->setLocale(numberLocale);
+	ui.sbBorderWidth->setLocale(numberLocale);
+	ui.sbErrorBarSize->setLocale(numberLocale);
+}
+
 //*************************************************************
 //**** SLOTs for changes triggered in DatapickerCurveWidget ***
 //*************************************************************
 //"General"-tab
 void DatapickerCurveWidget::xErrorTypeChanged(int index) {
-	if ( DatapickerCurve::ErrorType(index) != DatapickerCurve::NoError
-		|| m_curve->curveErrorTypes().y != DatapickerCurve::NoError )
+	if ( DatapickerCurve::ErrorType(index) != DatapickerCurve::ErrorType::NoError
+		|| m_curve->curveErrorTypes().y != DatapickerCurve::ErrorType::NoError )
 		hideErrorBarWidgets(false);
 	else
 		hideErrorBarWidgets(true);
@@ -203,8 +212,8 @@ void DatapickerCurveWidget::xErrorTypeChanged(int index) {
 }
 
 void DatapickerCurveWidget::yErrorTypeChanged(int index) {
-	if ( DatapickerCurve::ErrorType(index) != DatapickerCurve::NoError
-		|| m_curve->curveErrorTypes().x != DatapickerCurve::NoError )
+	if ( DatapickerCurve::ErrorType(index) != DatapickerCurve::ErrorType::NoError
+		|| m_curve->curveErrorTypes().x != DatapickerCurve::ErrorType::NoError )
 		hideErrorBarWidgets(false);
 	else
 		hideErrorBarWidgets(true);
@@ -222,7 +231,7 @@ void DatapickerCurveWidget::yErrorTypeChanged(int index) {
 void DatapickerCurveWidget::styleChanged(int index) {
 	auto style = Symbol::Style(index + 1);
 	//enable/disable the  filling options in the GUI depending on the currently selected points.
-	if (style != Symbol::Line && style != Symbol::Cross) {
+	if (style != Symbol::Style::Line && style != Symbol::Style::Cross) {
  		ui.cbFillingStyle->setEnabled(true);
 		bool noBrush = (Qt::BrushStyle(ui.cbFillingStyle->currentIndex()) == Qt::NoBrush);
 		ui.kcbFillingColor->setEnabled(!noBrush);
@@ -247,7 +256,7 @@ void DatapickerCurveWidget::sizeChanged(double value) {
 		return;
 
 	for (auto* curve : m_curveList)
-		curve->setPointSize( Worksheet::convertToSceneUnits(value, Worksheet::Point) );
+		curve->setPointSize( Worksheet::convertToSceneUnits(value, Worksheet::Unit::Point) );
 }
 
 void DatapickerCurveWidget::rotationChanged(int value) {
@@ -272,7 +281,7 @@ void DatapickerCurveWidget::errorBarSizeChanged(double value) {
 		return;
 
 	for (auto* curve : m_curveList)
-		curve->setPointErrorBarSize( Worksheet::convertToSceneUnits(value, Worksheet::Point) );
+		curve->setPointErrorBarSize( Worksheet::convertToSceneUnits(value, Worksheet::Unit::Point) );
 }
 
 void DatapickerCurveWidget::fillingStyleChanged(int index) {
@@ -382,7 +391,7 @@ void DatapickerCurveWidget::borderWidthChanged(double value) {
 	QPen pen;
 	for (auto* curve : m_curveList) {
 		pen = curve->pointPen();
-		pen.setWidthF( Worksheet::convertToSceneUnits(value, Worksheet::Point) );
+		pen.setWidthF( Worksheet::convertToSceneUnits(value, Worksheet::Unit::Point) );
 		curve->setPointPen(pen);
 	}
 }
@@ -396,7 +405,7 @@ void DatapickerCurveWidget::visibilityChanged(bool state) {
 }
 
 void DatapickerCurveWidget::updateSymbolWidgets() {
-	auto list = m_curve->children<DatapickerPoint>(AbstractAspect::IncludeHidden);
+	auto list = m_curve->children<DatapickerPoint>(AbstractAspect::ChildIndexFlag::IncludeHidden);
 	if (list.isEmpty()) {
 		ui.cbXErrorType->setEnabled(true);
 		ui.cbYErrorType->setEnabled(true);
@@ -439,13 +448,13 @@ void DatapickerCurveWidget::symbolStyleChanged(Symbol::Style style) {
 
 void DatapickerCurveWidget::symbolSizeChanged(qreal size) {
 	m_initializing = true;
-	ui.sbSize->setValue( Worksheet::convertFromSceneUnits(size, Worksheet::Point) );
+	ui.sbSize->setValue( Worksheet::convertFromSceneUnits(size, Worksheet::Unit::Point) );
 	m_initializing = false;
 }
 
 void DatapickerCurveWidget::symbolErrorBarSizeChanged(qreal size) {
 	m_initializing = true;
-	ui.sbErrorBarSize->setValue( Worksheet::convertFromSceneUnits(size, Worksheet::Point) );
+	ui.sbErrorBarSize->setValue( Worksheet::convertFromSceneUnits(size, Worksheet::Unit::Point) );
 	m_initializing = false;
 }
 
@@ -482,7 +491,7 @@ void DatapickerCurveWidget::symbolPenChanged(const QPen& pen) {
 	ui.cbBorderStyle->setCurrentIndex( (int) pen.style());
 	ui.kcbBorderColor->setColor( pen.color());
 	GuiTools::updatePenStyles(ui.cbBorderStyle, pen.color());
-	ui.sbBorderWidth->setValue( Worksheet::convertFromSceneUnits(pen.widthF(), Worksheet::Point));
+	ui.sbBorderWidth->setValue( Worksheet::convertFromSceneUnits(pen.widthF(), Worksheet::Unit::Point));
 	m_initializing = false;
 }
 
@@ -503,17 +512,17 @@ void DatapickerCurveWidget::load() {
 	ui.cbXErrorType->setCurrentIndex((int) m_curve->curveErrorTypes().x);
 	ui.cbYErrorType->setCurrentIndex((int) m_curve->curveErrorTypes().y);
 	ui.cbStyle->setCurrentIndex( (int)m_curve->pointStyle() - 1 );
-	ui.sbSize->setValue( Worksheet::convertFromSceneUnits(m_curve->pointSize(), Worksheet::Point) );
+	ui.sbSize->setValue( Worksheet::convertFromSceneUnits(m_curve->pointSize(), Worksheet::Unit::Point) );
 	ui.sbRotation->setValue( m_curve->pointRotationAngle() );
 	ui.sbOpacity->setValue( round(m_curve->pointOpacity()*100.0) );
 	ui.cbFillingStyle->setCurrentIndex( (int) m_curve->pointBrush().style() );
 	ui.kcbFillingColor->setColor(  m_curve->pointBrush().color() );
 	ui.cbBorderStyle->setCurrentIndex( (int) m_curve->pointPen().style() );
 	ui.kcbBorderColor->setColor( m_curve->pointPen().color() );
-	ui.sbBorderWidth->setValue( Worksheet::convertFromSceneUnits(m_curve->pointPen().widthF(), Worksheet::Point) );
+	ui.sbBorderWidth->setValue( Worksheet::convertFromSceneUnits(m_curve->pointPen().widthF(), Worksheet::Unit::Point) );
 	ui.chbVisible->setChecked( m_curve->pointVisibility() );
 	ui.cbErrorBarFillingStyle->setCurrentIndex( (int) m_curve->pointErrorBarBrush().style() );
 	ui.kcbErrorBarFillingColor->setColor(  m_curve->pointErrorBarBrush().color() );
-	ui.sbErrorBarSize->setValue( Worksheet::convertFromSceneUnits(m_curve->pointErrorBarSize(), Worksheet::Point) );
+	ui.sbErrorBarSize->setValue( Worksheet::convertFromSceneUnits(m_curve->pointErrorBarSize(), Worksheet::Unit::Point) );
 	m_initializing = false;
 }
