@@ -38,13 +38,13 @@ void CorrelationTest::testLinear() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column xDataColumn("x", AbstractColumn::Integer);
+	Column xDataColumn("x", AbstractColumn::ColumnMode::Integer);
 	xDataColumn.replaceInteger(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -91,13 +91,13 @@ void CorrelationTest::testLinear2() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column xDataColumn("x", AbstractColumn::Integer);
+	Column xDataColumn("x", AbstractColumn::ColumnMode::Integer);
 	xDataColumn.replaceInteger(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -140,10 +140,10 @@ void CorrelationTest::testLinear_noX() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -189,13 +189,13 @@ void CorrelationTest::testLinear_swapped() {
 	QVector<double> y2Data = {1.,2.,3.,4.};
 
 	//data source columns
-	Column xDataColumn("x", AbstractColumn::Integer);
+	Column xDataColumn("x", AbstractColumn::ColumnMode::Integer);
 	xDataColumn.replaceInteger(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -244,13 +244,13 @@ void CorrelationTest::testCircular() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column xDataColumn("x", AbstractColumn::Integer);
+	Column xDataColumn("x", AbstractColumn::ColumnMode::Integer);
 	xDataColumn.replaceInteger(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -297,13 +297,13 @@ void CorrelationTest::testCircular2() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column xDataColumn("x", AbstractColumn::Integer);
+	Column xDataColumn("x", AbstractColumn::ColumnMode::Integer);
 	xDataColumn.replaceInteger(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -349,10 +349,10 @@ void CorrelationTest::testLinear_biased() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -400,10 +400,10 @@ void CorrelationTest::testLinear2_biased() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -447,10 +447,10 @@ void CorrelationTest::testLinear_unbiased() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -498,10 +498,10 @@ void CorrelationTest::testLinear2_unbiased() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -545,10 +545,10 @@ void CorrelationTest::testLinear_coeff() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -597,10 +597,10 @@ void CorrelationTest::testLinear2_coeff() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -645,10 +645,10 @@ void CorrelationTest::testCircular_coeff() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -694,10 +694,10 @@ void CorrelationTest::testCircular2_coeff() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -743,10 +743,10 @@ void CorrelationTest::testLinear_samplingInterval() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -794,10 +794,10 @@ void CorrelationTest::testLinear2_samplingInterval() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -842,10 +842,10 @@ void CorrelationTest::testCircular_samplingInterval() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -889,10 +889,10 @@ void CorrelationTest::testCircular2_samplingInterval() {
 	QVector<double> y2Data = {0,1.,.5};
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
@@ -943,10 +943,10 @@ void CorrelationTest::testPerformance() {
 	}
 
 	//data source columns
-	Column yDataColumn("y", AbstractColumn::Numeric);
+	Column yDataColumn("y", AbstractColumn::ColumnMode::Numeric);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::Numeric);
+	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Numeric);
 	y2DataColumn.replaceValues(0, y2Data);
 
 	XYCorrelationCurve correlationCurve("correlation");
